from typing import Dict, List
from ergo_python_appkit.appkit import ErgoAppKit
from org.ergoplatform.appkit import ErgoContract, ErgoValue, InputBox, OutBox

class ErgoBox:
    def __init__(self, appKit: ErgoAppKit, value: int, contract: ErgoContract, tokens: Dict[str, int] = None, registers: List[ErgoValue] = None) -> None:
        self.appKit = appKit
        self.value = value
        self.contract = contract
        self.tokens = tokens
        self.registers = registers

    @property
    def outBox(self) -> OutBox:
        return self.appKit.buildOutBox(self.value,self.tokens,self.registers,self.contract)

    def inputBox(self, txId: str = "ce552663312afc2379a91f803c93e2b10b424f176fbc930055c10def2fd88a5d", index: int = 0) -> InputBox:
        return self.appKit.buildOutBox(self.value,self.tokens,self.registers,self.contract).convertToInputWith(txId,index)

    @property
    def appKit(self) -> ErgoAppKit:
        return self._appKit
    @appKit.setter
    def appKit(self, appKit: ErgoAppKit) -> None:
        self._appKit = appKit

    @property
    def value(self) -> int:
        return self._value
    @value.setter
    def value(self, value: int) -> None:
        self._value = value

    @property
    def contract(self) -> ErgoContract:
        return self._contract
    @contract.setter
    def contract(self, contract: ErgoContract) -> None:
        self._contract = contract

    @property
    def tokens(self) -> Dict[str, int]:
        return self._tokens
    @tokens.setter
    def tokens(self, tokens: Dict[str, int]) -> None:
        self._tokens = tokens

    @property
    def registers(self) -> List[ErgoValue]:
        return self._registers
    @registers.setter
    def registers(self, registers: List[ErgoValue]) -> None:
        self._registers = registers


import java.util
import typing



_BiConsumer__T = typing.TypeVar('_BiConsumer__T')  # <T>
_BiConsumer__U = typing.TypeVar('_BiConsumer__U')  # <U>
class BiConsumer(typing.Generic[_BiConsumer__T, _BiConsumer__U]):
    def accept(self, t: _BiConsumer__T, u: _BiConsumer__U) -> None: ...
    def andThen(self, biConsumer: typing.Union['BiConsumer'[_BiConsumer__T, _BiConsumer__U], typing.Callable[[_BiConsumer__T, _BiConsumer__U], None]]) -> 'BiConsumer'[_BiConsumer__T, _BiConsumer__U]: ...

_BiFunction__T = typing.TypeVar('_BiFunction__T')  # <T>
_BiFunction__U = typing.TypeVar('_BiFunction__U')  # <U>
_BiFunction__R = typing.TypeVar('_BiFunction__R')  # <R>
class BiFunction(typing.Generic[_BiFunction__T, _BiFunction__U, _BiFunction__R]):
    _andThen__V = typing.TypeVar('_andThen__V')  # <V>
    def andThen(self, function: typing.Union['Function'[_BiFunction__R, _andThen__V], typing.Callable[[_BiFunction__R], _andThen__V]]) -> 'BiFunction'[_BiFunction__T, _BiFunction__U, _andThen__V]: ...
    def apply(self, t: _BiFunction__T, u: _BiFunction__U) -> _BiFunction__R: ...

_BiPredicate__T = typing.TypeVar('_BiPredicate__T')  # <T>
_BiPredicate__U = typing.TypeVar('_BiPredicate__U')  # <U>
class BiPredicate(typing.Generic[_BiPredicate__T, _BiPredicate__U]):
    def negate(self) -> 'BiPredicate'[_BiPredicate__T, _BiPredicate__U]: ...
    def test(self, t: _BiPredicate__T, u: _BiPredicate__U) -> bool: ...

class BooleanSupplier:
    def getAsBoolean(self) -> bool: ...

_Consumer__T = typing.TypeVar('_Consumer__T')  # <T>
class Consumer(typing.Generic[_Consumer__T]):
    def accept(self, t: _Consumer__T) -> None: ...
    def andThen(self, consumer: typing.Union['Consumer'[_Consumer__T], typing.Callable[[_Consumer__T], None]]) -> 'Consumer'[_Consumer__T]: ...

class DoubleBinaryOperator:
    def applyAsDouble(self, double: float, double2: float) -> float: ...

class DoubleConsumer:
    def accept(self, double: float) -> None: ...
    def andThen(self, doubleConsumer: typing.Union['DoubleConsumer', typing.Callable]) -> 'DoubleConsumer': ...

_DoubleFunction__R = typing.TypeVar('_DoubleFunction__R')  # <R>
class DoubleFunction(typing.Generic[_DoubleFunction__R]):
    def apply(self, double: float) -> _DoubleFunction__R: ...

class DoublePredicate:
    def negate(self) -> 'DoublePredicate': ...
    def test(self, double: float) -> bool: ...

class DoubleSupplier:
    def getAsDouble(self) -> float: ...

class DoubleToIntFunction:
    def applyAsInt(self, double: float) -> int: ...

class DoubleToLongFunction:
    def applyAsLong(self, double: float) -> int: ...

class DoubleUnaryOperator:
    def andThen(self, doubleUnaryOperator: typing.Union['DoubleUnaryOperator', typing.Callable]) -> 'DoubleUnaryOperator': ...
    def applyAsDouble(self, double: float) -> float: ...
    def compose(self, doubleUnaryOperator: typing.Union['DoubleUnaryOperator', typing.Callable]) -> 'DoubleUnaryOperator': ...
    @staticmethod
    def identity() -> 'DoubleUnaryOperator': ...

_Function__T = typing.TypeVar('_Function__T')  # <T>
_Function__R = typing.TypeVar('_Function__R')  # <R>
class Function(typing.Generic[_Function__T, _Function__R]):
    _andThen__V = typing.TypeVar('_andThen__V')  # <V>
    def andThen(self, function: typing.Union['Function'[_Function__R, _andThen__V], typing.Callable[[_Function__R], _andThen__V]]) -> 'Function'[_Function__T, _andThen__V]: ...
    def apply(self, t: _Function__T) -> _Function__R: ...
    _compose__V = typing.TypeVar('_compose__V')  # <V>
    def compose(self, function: typing.Union['Function'[_compose__V, _Function__T], typing.Callable[[_compose__V], _Function__T]]) -> 'Function'[_compose__V, _Function__R]: ...
    _identity__T = typing.TypeVar('_identity__T')  # <T>
    @staticmethod
    def identity() -> 'Function'[_identity__T, _identity__T]: ...

class IntBinaryOperator:
    def applyAsInt(self, int: int, int2: int) -> int: ...

class IntConsumer:
    def accept(self, int: int) -> None: ...
    def andThen(self, intConsumer: typing.Union['IntConsumer', typing.Callable]) -> 'IntConsumer': ...

_IntFunction__R = typing.TypeVar('_IntFunction__R')  # <R>
class IntFunction(typing.Generic[_IntFunction__R]):
    def apply(self, int: int) -> _IntFunction__R: ...

class IntPredicate:
    def negate(self) -> 'IntPredicate': ...
    def test(self, int: int) -> bool: ...

class IntSupplier:
    def getAsInt(self) -> int: ...

class IntToDoubleFunction:
    def applyAsDouble(self, int: int) -> float: ...

class IntToLongFunction:
    def applyAsLong(self, int: int) -> int: ...

class IntUnaryOperator:
    def andThen(self, intUnaryOperator: typing.Union['IntUnaryOperator', typing.Callable]) -> 'IntUnaryOperator': ...
    def applyAsInt(self, int: int) -> int: ...
    def compose(self, intUnaryOperator: typing.Union['IntUnaryOperator', typing.Callable]) -> 'IntUnaryOperator': ...
    @staticmethod
    def identity() -> 'IntUnaryOperator': ...

class LongBinaryOperator:
    def applyAsLong(self, long: int, long2: int) -> int: ...

class LongConsumer:
    def accept(self, long: int) -> None: ...
    def andThen(self, longConsumer: typing.Union['LongConsumer', typing.Callable]) -> 'LongConsumer': ...

_LongFunction__R = typing.TypeVar('_LongFunction__R')  # <R>
class LongFunction(typing.Generic[_LongFunction__R]):
    def apply(self, long: int) -> _LongFunction__R: ...

class LongPredicate:
    def negate(self) -> 'LongPredicate': ...
    def test(self, long: int) -> bool: ...

class LongSupplier:
    def getAsLong(self) -> int: ...

class LongToDoubleFunction:
    def applyAsDouble(self, long: int) -> float: ...

class LongToIntFunction:
    def applyAsInt(self, long: int) -> int: ...

class LongUnaryOperator:
    def andThen(self, longUnaryOperator: typing.Union['LongUnaryOperator', typing.Callable]) -> 'LongUnaryOperator': ...
    def applyAsLong(self, long: int) -> int: ...
    def compose(self, longUnaryOperator: typing.Union['LongUnaryOperator', typing.Callable]) -> 'LongUnaryOperator': ...
    @staticmethod
    def identity() -> 'LongUnaryOperator': ...

_ObjDoubleConsumer__T = typing.TypeVar('_ObjDoubleConsumer__T')  # <T>
class ObjDoubleConsumer(typing.Generic[_ObjDoubleConsumer__T]):
    def accept(self, t: _ObjDoubleConsumer__T, double: float) -> None: ...

_ObjIntConsumer__T = typing.TypeVar('_ObjIntConsumer__T')  # <T>
class ObjIntConsumer(typing.Generic[_ObjIntConsumer__T]):
    def accept(self, t: _ObjIntConsumer__T, int: int) -> None: ...

_ObjLongConsumer__T = typing.TypeVar('_ObjLongConsumer__T')  # <T>
class ObjLongConsumer(typing.Generic[_ObjLongConsumer__T]):
    def accept(self, t: _ObjLongConsumer__T, long: int) -> None: ...

_Predicate__T = typing.TypeVar('_Predicate__T')  # <T>
class Predicate(typing.Generic[_Predicate__T]):
    _isEqual__T = typing.TypeVar('_isEqual__T')  # <T>
    @staticmethod
    def isEqual(object: typing.Any) -> 'Predicate'[_isEqual__T]: ...
    def negate(self) -> 'Predicate'[_Predicate__T]: ...
    def test(self, t: _Predicate__T) -> bool: ...

_Supplier__T = typing.TypeVar('_Supplier__T')  # <T>
class Supplier(typing.Generic[_Supplier__T]):
    def get(self) -> _Supplier__T: ...

_ToDoubleBiFunction__T = typing.TypeVar('_ToDoubleBiFunction__T')  # <T>
_ToDoubleBiFunction__U = typing.TypeVar('_ToDoubleBiFunction__U')  # <U>
class ToDoubleBiFunction(typing.Generic[_ToDoubleBiFunction__T, _ToDoubleBiFunction__U]):
    def applyAsDouble(self, t: _ToDoubleBiFunction__T, u: _ToDoubleBiFunction__U) -> float: ...

_ToDoubleFunction__T = typing.TypeVar('_ToDoubleFunction__T')  # <T>
class ToDoubleFunction(typing.Generic[_ToDoubleFunction__T]):
    def applyAsDouble(self, t: _ToDoubleFunction__T) -> float: ...

_ToIntBiFunction__T = typing.TypeVar('_ToIntBiFunction__T')  # <T>
_ToIntBiFunction__U = typing.TypeVar('_ToIntBiFunction__U')  # <U>
class ToIntBiFunction(typing.Generic[_ToIntBiFunction__T, _ToIntBiFunction__U]):
    def applyAsInt(self, t: _ToIntBiFunction__T, u: _ToIntBiFunction__U) -> int: ...

_ToIntFunction__T = typing.TypeVar('_ToIntFunction__T')  # <T>
class ToIntFunction(typing.Generic[_ToIntFunction__T]):
    def applyAsInt(self, t: _ToIntFunction__T) -> int: ...

_ToLongBiFunction__T = typing.TypeVar('_ToLongBiFunction__T')  # <T>
_ToLongBiFunction__U = typing.TypeVar('_ToLongBiFunction__U')  # <U>
class ToLongBiFunction(typing.Generic[_ToLongBiFunction__T, _ToLongBiFunction__U]):
    def applyAsLong(self, t: _ToLongBiFunction__T, u: _ToLongBiFunction__U) -> int: ...

_ToLongFunction__T = typing.TypeVar('_ToLongFunction__T')  # <T>
class ToLongFunction(typing.Generic[_ToLongFunction__T]):
    def applyAsLong(self, t: _ToLongFunction__T) -> int: ...

_BinaryOperator__T = typing.TypeVar('_BinaryOperator__T')  # <T>
class BinaryOperator(BiFunction[_BinaryOperator__T, _BinaryOperator__T, _BinaryOperator__T], typing.Generic[_BinaryOperator__T]):
    _maxBy__T = typing.TypeVar('_maxBy__T')  # <T>
    @staticmethod
    def maxBy(comparator: typing.Union[java.util.Comparator[_maxBy__T], typing.Callable[[_maxBy__T, _maxBy__T], int]]) -> 'BinaryOperator'[_maxBy__T]: ...
    _minBy__T = typing.TypeVar('_minBy__T')  # <T>
    @staticmethod
    def minBy(comparator: typing.Union[java.util.Comparator[_minBy__T], typing.Callable[[_minBy__T, _minBy__T], int]]) -> 'BinaryOperator'[_minBy__T]: ...

_UnaryOperator__T = typing.TypeVar('_UnaryOperator__T')  # <T>
class UnaryOperator(Function[_UnaryOperator__T, _UnaryOperator__T], typing.Generic[_UnaryOperator__T]):
    _identity__T = typing.TypeVar('_identity__T')  # <T>
    @staticmethod
    def identity() -> 'UnaryOperator'[_identity__T]: ...


class __module_protocol__(typing.Protocol):
    # A module protocol which reflects the result of ``jp.JPackage("java.util.function")``.

    BiConsumer: typing.Type[BiConsumer]
    BiFunction: typing.Type[BiFunction]
    BiPredicate: typing.Type[BiPredicate]
    BinaryOperator: typing.Type[BinaryOperator]
    BooleanSupplier: typing.Type[BooleanSupplier]
    Consumer: typing.Type[Consumer]
    DoubleBinaryOperator: typing.Type[DoubleBinaryOperator]
    DoubleConsumer: typing.Type[DoubleConsumer]
    DoubleFunction: typing.Type[DoubleFunction]
    DoublePredicate: typing.Type[DoublePredicate]
    DoubleSupplier: typing.Type[DoubleSupplier]
    DoubleToIntFunction: typing.Type[DoubleToIntFunction]
    DoubleToLongFunction: typing.Type[DoubleToLongFunction]
    DoubleUnaryOperator: typing.Type[DoubleUnaryOperator]
    Function: typing.Type[Function]
    IntBinaryOperator: typing.Type[IntBinaryOperator]
    IntConsumer: typing.Type[IntConsumer]
    IntFunction: typing.Type[IntFunction]
    IntPredicate: typing.Type[IntPredicate]
    IntSupplier: typing.Type[IntSupplier]
    IntToDoubleFunction: typing.Type[IntToDoubleFunction]
    IntToLongFunction: typing.Type[IntToLongFunction]
    IntUnaryOperator: typing.Type[IntUnaryOperator]
    LongBinaryOperator: typing.Type[LongBinaryOperator]
    LongConsumer: typing.Type[LongConsumer]
    LongFunction: typing.Type[LongFunction]
    LongPredicate: typing.Type[LongPredicate]
    LongSupplier: typing.Type[LongSupplier]
    LongToDoubleFunction: typing.Type[LongToDoubleFunction]
    LongToIntFunction: typing.Type[LongToIntFunction]
    LongUnaryOperator: typing.Type[LongUnaryOperator]
    ObjDoubleConsumer: typing.Type[ObjDoubleConsumer]
    ObjIntConsumer: typing.Type[ObjIntConsumer]
    ObjLongConsumer: typing.Type[ObjLongConsumer]
    Predicate: typing.Type[Predicate]
    Supplier: typing.Type[Supplier]
    ToDoubleBiFunction: typing.Type[ToDoubleBiFunction]
    ToDoubleFunction: typing.Type[ToDoubleFunction]
    ToIntBiFunction: typing.Type[ToIntBiFunction]
    ToIntFunction: typing.Type[ToIntFunction]
    ToLongBiFunction: typing.Type[ToLongBiFunction]
    ToLongFunction: typing.Type[ToLongFunction]
    UnaryOperator: typing.Type[UnaryOperator]



import java.awt
import java.awt.color
import java.awt.geom
import java.awt.image.renderable
import java.lang
import java.math
import java.util
import typing



class BufferStrategy:
    def __init__(self): ...
    def contentsLost(self) -> bool: ...
    def contentsRestored(self) -> bool: ...
    def dispose(self) -> None: ...
    def getCapabilities(self) -> java.awt.BufferCapabilities: ...
    def getDrawGraphics(self) -> java.awt.Graphics: ...
    def show(self) -> None: ...

class BufferedImageOp:
    def createCompatibleDestImage(self, bufferedImage: 'BufferedImage', colorModel: 'ColorModel') -> 'BufferedImage': ...
    def filter(self, bufferedImage: 'BufferedImage', bufferedImage2: 'BufferedImage') -> 'BufferedImage': ...
    def getBounds2D(self, bufferedImage: 'BufferedImage') -> java.awt.geom.Rectangle2D: ...
    def getPoint2D(self, point2D: java.awt.geom.Point2D, point2D2: java.awt.geom.Point2D) -> java.awt.geom.Point2D: ...
    def getRenderingHints(self) -> java.awt.RenderingHints: ...

class ColorModel(java.awt.Transparency):
    def __init__(self, int: int): ...
    def coerceData(self, writableRaster: 'WritableRaster', boolean: bool) -> 'ColorModel': ...
    def createCompatibleSampleModel(self, int: int, int2: int) -> 'SampleModel': ...
    def createCompatibleWritableRaster(self, int: int, int2: int) -> 'WritableRaster': ...
    def equals(self, object: typing.Any) -> bool: ...
    def finalize(self) -> None: ...
    @typing.overload
    def getAlpha(self, int: int) -> int: ...
    @typing.overload
    def getAlpha(self, object: typing.Any) -> int: ...
    def getAlphaRaster(self, writableRaster: 'WritableRaster') -> 'WritableRaster': ...
    @typing.overload
    def getBlue(self, int: int) -> int: ...
    @typing.overload
    def getBlue(self, object: typing.Any) -> int: ...
    def getColorSpace(self) -> java.awt.color.ColorSpace: ...
    @typing.overload
    def getComponentSize(self, int: int) -> int: ...
    @typing.overload
    def getComponentSize(self) -> typing.List[int]: ...
    @typing.overload
    def getComponents(self, int: int, intArray: typing.List[int], int3: int) -> typing.List[int]: ...
    @typing.overload
    def getComponents(self, object: typing.Any, intArray: typing.List[int], int2: int) -> typing.List[int]: ...
    @typing.overload
    def getDataElement(self, floatArray: typing.List[float], int: int) -> int: ...
    @typing.overload
    def getDataElement(self, intArray: typing.List[int], int2: int) -> int: ...
    @typing.overload
    def getDataElements(self, floatArray: typing.List[float], int: int, object: typing.Any) -> typing.Any: ...
    @typing.overload
    def getDataElements(self, int: int, object: typing.Any) -> typing.Any: ...
    @typing.overload
    def getDataElements(self, intArray: typing.List[int], int2: int, object: typing.Any) -> typing.Any: ...
    @typing.overload
    def getGreen(self, int: int) -> int: ...
    @typing.overload
    def getGreen(self, object: typing.Any) -> int: ...
    @typing.overload
    def getNormalizedComponents(self, intArray: typing.List[int], int2: int, floatArray: typing.List[float], int3: int) -> typing.List[float]: ...
    @typing.overload
    def getNormalizedComponents(self, object: typing.Any, floatArray: typing.List[float], int: int) -> typing.List[float]: ...
    def getNumColorComponents(self) -> int: ...
    def getNumComponents(self) -> int: ...
    def getPixelSize(self) -> int: ...
    @typing.overload
    def getRGB(self, int: int) -> int: ...
    @typing.overload
    def getRGB(self, object: typing.Any) -> int: ...
    @staticmethod
    def getRGBdefault() -> 'ColorModel': ...
    @typing.overload
    def getRed(self, int: int) -> int: ...
    @typing.overload
    def getRed(self, object: typing.Any) -> int: ...
    def getTransferType(self) -> int: ...
    def getTransparency(self) -> int: ...
    def getUnnormalizedComponents(self, floatArray: typing.List[float], int: int, intArray: typing.List[int], int3: int) -> typing.List[int]: ...
    def hasAlpha(self) -> bool: ...
    def hashCode(self) -> int: ...
    def isAlphaPremultiplied(self) -> bool: ...
    def isCompatibleRaster(self, raster: 'Raster') -> bool: ...
    def isCompatibleSampleModel(self, sampleModel: 'SampleModel') -> bool: ...
    def toString(self) -> str: ...

class DataBuffer:
    TYPE_BYTE: typing.ClassVar[int] = ...
    TYPE_USHORT: typing.ClassVar[int] = ...
    TYPE_SHORT: typing.ClassVar[int] = ...
    TYPE_INT: typing.ClassVar[int] = ...
    TYPE_FLOAT: typing.ClassVar[int] = ...
    TYPE_DOUBLE: typing.ClassVar[int] = ...
    TYPE_UNDEFINED: typing.ClassVar[int] = ...
    def getDataType(self) -> int: ...
    @staticmethod
    def getDataTypeSize(int: int) -> int: ...
    @typing.overload
    def getElem(self, int: int, int2: int) -> int: ...
    @typing.overload
    def getElem(self, int: int) -> int: ...
    @typing.overload
    def getElemDouble(self, int: int) -> float: ...
    @typing.overload
    def getElemDouble(self, int: int, int2: int) -> float: ...
    @typing.overload
    def getElemFloat(self, int: int) -> float: ...
    @typing.overload
    def getElemFloat(self, int: int, int2: int) -> float: ...
    def getNumBanks(self) -> int: ...
    def getOffset(self) -> int: ...
    def getOffsets(self) -> typing.List[int]: ...
    def getSize(self) -> int: ...
    @typing.overload
    def setElem(self, int: int, int2: int, int3: int) -> None: ...
    @typing.overload
    def setElem(self, int: int, int2: int) -> None: ...
    @typing.overload
    def setElemDouble(self, int: int, double: float) -> None: ...
    @typing.overload
    def setElemDouble(self, int: int, int2: int, double: float) -> None: ...
    @typing.overload
    def setElemFloat(self, int: int, float: float) -> None: ...
    @typing.overload
    def setElemFloat(self, int: int, int2: int, float: float) -> None: ...

class ImageConsumer:
    RANDOMPIXELORDER: typing.ClassVar[int] = ...
    TOPDOWNLEFTRIGHT: typing.ClassVar[int] = ...
    COMPLETESCANLINES: typing.ClassVar[int] = ...
    SINGLEPASS: typing.ClassVar[int] = ...
    SINGLEFRAME: typing.ClassVar[int] = ...
    IMAGEERROR: typing.ClassVar[int] = ...
    SINGLEFRAMEDONE: typing.ClassVar[int] = ...
    STATICIMAGEDONE: typing.ClassVar[int] = ...
    IMAGEABORTED: typing.ClassVar[int] = ...
    def imageComplete(self, int: int) -> None: ...
    def setColorModel(self, colorModel: ColorModel) -> None: ...
    def setDimensions(self, int: int, int2: int) -> None: ...
    def setHints(self, int: int) -> None: ...
    @typing.overload
    def setPixels(self, int: int, int2: int, int3: int, int4: int, colorModel: ColorModel, byteArray: typing.List[int], int5: int, int6: int) -> None: ...
    @typing.overload
    def setPixels(self, int: int, int2: int, int3: int, int4: int, colorModel: ColorModel, intArray: typing.List[int], int6: int, int7: int) -> None: ...
    def setProperties(self, hashtable: java.util.Hashtable[typing.Any, typing.Any]) -> None: ...

class ImageObserver:
    WIDTH: typing.ClassVar[int] = ...
    HEIGHT: typing.ClassVar[int] = ...
    PROPERTIES: typing.ClassVar[int] = ...
    SOMEBITS: typing.ClassVar[int] = ...
    FRAMEBITS: typing.ClassVar[int] = ...
    ALLBITS: typing.ClassVar[int] = ...
    ERROR: typing.ClassVar[int] = ...
    ABORT: typing.ClassVar[int] = ...
    def imageUpdate(self, image: java.awt.Image, int: int, int2: int, int3: int, int4: int, int5: int) -> bool: ...

class ImageProducer:
    def addConsumer(self, imageConsumer: ImageConsumer) -> None: ...
    def isConsumer(self, imageConsumer: ImageConsumer) -> bool: ...
    def removeConsumer(self, imageConsumer: ImageConsumer) -> None: ...
    def requestTopDownLeftRightResend(self, imageConsumer: ImageConsumer) -> None: ...
    def startProduction(self, imageConsumer: ImageConsumer) -> None: ...

class ImagingOpException(java.lang.RuntimeException):
    def __init__(self, string: str): ...

class Kernel(java.lang.Cloneable):
    def __init__(self, int: int, int2: int, floatArray: typing.List[float]): ...
    def clone(self) -> typing.Any: ...
    def getHeight(self) -> int: ...
    def getKernelData(self, floatArray: typing.List[float]) -> typing.List[float]: ...
    def getWidth(self) -> int: ...
    def getXOrigin(self) -> int: ...
    def getYOrigin(self) -> int: ...

class LookupTable:
    def getNumComponents(self) -> int: ...
    def getOffset(self) -> int: ...
    def lookupPixel(self, intArray: typing.List[int], intArray2: typing.List[int]) -> typing.List[int]: ...

class MultiResolutionImage:
    def getResolutionVariant(self, double: float, double2: float) -> java.awt.Image: ...
    def getResolutionVariants(self) -> java.util.List[java.awt.Image]: ...

class Raster:
    @typing.overload
    @staticmethod
    def createBandedRaster(int: int, int2: int, int3: int, int4: int, intArray: typing.List[int], intArray2: typing.List[int], point: java.awt.Point) -> 'WritableRaster': ...
    @typing.overload
    @staticmethod
    def createBandedRaster(int: int, int2: int, int3: int, int4: int, point: java.awt.Point) -> 'WritableRaster': ...
    @typing.overload
    @staticmethod
    def createBandedRaster(dataBuffer: DataBuffer, int: int, int2: int, int3: int, intArray: typing.List[int], intArray2: typing.List[int], point: java.awt.Point) -> 'WritableRaster': ...
    def createChild(self, int: int, int2: int, int3: int, int4: int, int5: int, int6: int, intArray: typing.List[int]) -> 'Raster': ...
    @typing.overload
    def createCompatibleWritableRaster(self) -> 'WritableRaster': ...
    @typing.overload
    def createCompatibleWritableRaster(self, int: int, int2: int) -> 'WritableRaster': ...
    @typing.overload
    def createCompatibleWritableRaster(self, int: int, int2: int, int3: int, int4: int) -> 'WritableRaster': ...
    @typing.overload
    def createCompatibleWritableRaster(self, rectangle: java.awt.Rectangle) -> 'WritableRaster': ...
    @typing.overload
    @staticmethod
    def createInterleavedRaster(int: int, int2: int, int3: int, int4: int, int5: int, intArray: typing.List[int], point: java.awt.Point) -> 'WritableRaster': ...
    @typing.overload
    @staticmethod
    def createInterleavedRaster(int: int, int2: int, int3: int, int4: int, point: java.awt.Point) -> 'WritableRaster': ...
    @typing.overload
    @staticmethod
    def createInterleavedRaster(dataBuffer: DataBuffer, int: int, int2: int, int3: int, int4: int, intArray: typing.List[int], point: java.awt.Point) -> 'WritableRaster': ...
    @typing.overload
    @staticmethod
    def createPackedRaster(int: int, int2: int, int3: int, int4: int, int5: int, point: java.awt.Point) -> 'WritableRaster': ...
    @typing.overload
    @staticmethod
    def createPackedRaster(int: int, int2: int, int3: int, intArray: typing.List[int], point: java.awt.Point) -> 'WritableRaster': ...
    @typing.overload
    @staticmethod
    def createPackedRaster(dataBuffer: DataBuffer, int: int, int2: int, int3: int, intArray: typing.List[int], point: java.awt.Point) -> 'WritableRaster': ...
    @typing.overload
    @staticmethod
    def createPackedRaster(dataBuffer: DataBuffer, int: int, int2: int, int3: int, point: java.awt.Point) -> 'WritableRaster': ...
    @staticmethod
    def createRaster(sampleModel: 'SampleModel', dataBuffer: DataBuffer, point: java.awt.Point) -> 'Raster': ...
    def createTranslatedChild(self, int: int, int2: int) -> 'Raster': ...
    @typing.overload
    @staticmethod
    def createWritableRaster(sampleModel: 'SampleModel', point: java.awt.Point) -> 'WritableRaster': ...
    @typing.overload
    @staticmethod
    def createWritableRaster(sampleModel: 'SampleModel', dataBuffer: DataBuffer, point: java.awt.Point) -> 'WritableRaster': ...
    def getBounds(self) -> java.awt.Rectangle: ...
    def getDataBuffer(self) -> DataBuffer: ...
    @typing.overload
    def getDataElements(self, int: int, int2: int, int3: int, int4: int, object: typing.Any) -> typing.Any: ...
    @typing.overload
    def getDataElements(self, int: int, int2: int, object: typing.Any) -> typing.Any: ...
    def getHeight(self) -> int: ...
    def getMinX(self) -> int: ...
    def getMinY(self) -> int: ...
    def getNumBands(self) -> int: ...
    def getNumDataElements(self) -> int: ...
    def getParent(self) -> 'Raster': ...
    @typing.overload
    def getPixel(self, int: int, int2: int, doubleArray: typing.List[float]) -> typing.List[float]: ...
    @typing.overload
    def getPixel(self, int: int, int2: int, floatArray: typing.List[float]) -> typing.List[float]: ...
    @typing.overload
    def getPixel(self, int: int, int2: int, intArray: typing.List[int]) -> typing.List[int]: ...
    @typing.overload
    def getPixels(self, int: int, int2: int, int3: int, int4: int, doubleArray: typing.List[float]) -> typing.List[float]: ...
    @typing.overload
    def getPixels(self, int: int, int2: int, int3: int, int4: int, floatArray: typing.List[float]) -> typing.List[float]: ...
    @typing.overload
    def getPixels(self, int: int, int2: int, int3: int, int4: int, intArray: typing.List[int]) -> typing.List[int]: ...
    def getSample(self, int: int, int2: int, int3: int) -> int: ...
    def getSampleDouble(self, int: int, int2: int, int3: int) -> float: ...
    def getSampleFloat(self, int: int, int2: int, int3: int) -> float: ...
    def getSampleModel(self) -> 'SampleModel': ...
    def getSampleModelTranslateX(self) -> int: ...
    def getSampleModelTranslateY(self) -> int: ...
    @typing.overload
    def getSamples(self, int: int, int2: int, int3: int, int4: int, int5: int, doubleArray: typing.List[float]) -> typing.List[float]: ...
    @typing.overload
    def getSamples(self, int: int, int2: int, int3: int, int4: int, int5: int, floatArray: typing.List[float]) -> typing.List[float]: ...
    @typing.overload
    def getSamples(self, int: int, int2: int, int3: int, int4: int, int5: int, intArray: typing.List[int]) -> typing.List[int]: ...
    def getTransferType(self) -> int: ...
    def getWidth(self) -> int: ...

class RasterFormatException(java.lang.RuntimeException):
    def __init__(self, string: str): ...

class RasterOp:
    def createCompatibleDestRaster(self, raster: Raster) -> 'WritableRaster': ...
    def filter(self, raster: Raster, writableRaster: 'WritableRaster') -> 'WritableRaster': ...
    def getBounds2D(self, raster: Raster) -> java.awt.geom.Rectangle2D: ...
    def getPoint2D(self, point2D: java.awt.geom.Point2D, point2D2: java.awt.geom.Point2D) -> java.awt.geom.Point2D: ...
    def getRenderingHints(self) -> java.awt.RenderingHints: ...

class RenderedImage:
    def copyData(self, writableRaster: 'WritableRaster') -> 'WritableRaster': ...
    def getColorModel(self) -> ColorModel: ...
    @typing.overload
    def getData(self) -> Raster: ...
    @typing.overload
    def getData(self, rectangle: java.awt.Rectangle) -> Raster: ...
    def getHeight(self) -> int: ...
    def getMinTileX(self) -> int: ...
    def getMinTileY(self) -> int: ...
    def getMinX(self) -> int: ...
    def getMinY(self) -> int: ...
    def getNumXTiles(self) -> int: ...
    def getNumYTiles(self) -> int: ...
    def getProperty(self, string: str) -> typing.Any: ...
    def getPropertyNames(self) -> typing.List[str]: ...
    def getSampleModel(self) -> 'SampleModel': ...
    def getSources(self) -> java.util.Vector['RenderedImage']: ...
    def getTile(self, int: int, int2: int) -> Raster: ...
    def getTileGridXOffset(self) -> int: ...
    def getTileGridYOffset(self) -> int: ...
    def getTileHeight(self) -> int: ...
    def getTileWidth(self) -> int: ...
    def getWidth(self) -> int: ...

class SampleModel:
    def __init__(self, int: int, int2: int, int3: int, int4: int): ...
    def createCompatibleSampleModel(self, int: int, int2: int) -> 'SampleModel': ...
    def createDataBuffer(self) -> DataBuffer: ...
    def createSubsetSampleModel(self, intArray: typing.List[int]) -> 'SampleModel': ...
    @typing.overload
    def getDataElements(self, int: int, int2: int, object: typing.Any, dataBuffer: DataBuffer) -> typing.Any: ...
    @typing.overload
    def getDataElements(self, int: int, int2: int, int3: int, int4: int, object: typing.Any, dataBuffer: DataBuffer) -> typing.Any: ...
    def getDataType(self) -> int: ...
    def getHeight(self) -> int: ...
    def getNumBands(self) -> int: ...
    def getNumDataElements(self) -> int: ...
    @typing.overload
    def getPixel(self, int: int, int2: int, doubleArray: typing.List[float], dataBuffer: DataBuffer) -> typing.List[float]: ...
    @typing.overload
    def getPixel(self, int: int, int2: int, floatArray: typing.List[float], dataBuffer: DataBuffer) -> typing.List[float]: ...
    @typing.overload
    def getPixel(self, int: int, int2: int, intArray: typing.List[int], dataBuffer: DataBuffer) -> typing.List[int]: ...
    @typing.overload
    def getPixels(self, int: int, int2: int, int3: int, int4: int, doubleArray: typing.List[float], dataBuffer: DataBuffer) -> typing.List[float]: ...
    @typing.overload
    def getPixels(self, int: int, int2: int, int3: int, int4: int, floatArray: typing.List[float], dataBuffer: DataBuffer) -> typing.List[float]: ...
    @typing.overload
    def getPixels(self, int: int, int2: int, int3: int, int4: int, intArray: typing.List[int], dataBuffer: DataBuffer) -> typing.List[int]: ...
    def getSample(self, int: int, int2: int, int3: int, dataBuffer: DataBuffer) -> int: ...
    def getSampleDouble(self, int: int, int2: int, int3: int, dataBuffer: DataBuffer) -> float: ...
    def getSampleFloat(self, int: int, int2: int, int3: int, dataBuffer: DataBuffer) -> float: ...
    @typing.overload
    def getSampleSize(self, int: int) -> int: ...
    @typing.overload
    def getSampleSize(self) -> typing.List[int]: ...
    @typing.overload
    def getSamples(self, int: int, int2: int, int3: int, int4: int, int5: int, doubleArray: typing.List[float], dataBuffer: DataBuffer) -> typing.List[float]: ...
    @typing.overload
    def getSamples(self, int: int, int2: int, int3: int, int4: int, int5: int, floatArray: typing.List[float], dataBuffer: DataBuffer) -> typing.List[float]: ...
    @typing.overload
    def getSamples(self, int: int, int2: int, int3: int, int4: int, int5: int, intArray: typing.List[int], dataBuffer: DataBuffer) -> typing.List[int]: ...
    def getTransferType(self) -> int: ...
    def getWidth(self) -> int: ...
    @typing.overload
    def setDataElements(self, int: int, int2: int, object: typing.Any, dataBuffer: DataBuffer) -> None: ...
    @typing.overload
    def setDataElements(self, int: int, int2: int, int3: int, int4: int, object: typing.Any, dataBuffer: DataBuffer) -> None: ...
    @typing.overload
    def setPixel(self, int: int, int2: int, doubleArray: typing.List[float], dataBuffer: DataBuffer) -> None: ...
    @typing.overload
    def setPixel(self, int: int, int2: int, floatArray: typing.List[float], dataBuffer: DataBuffer) -> None: ...
    @typing.overload
    def setPixel(self, int: int, int2: int, intArray: typing.List[int], dataBuffer: DataBuffer) -> None: ...
    @typing.overload
    def setPixels(self, int: int, int2: int, int3: int, int4: int, doubleArray: typing.List[float], dataBuffer: DataBuffer) -> None: ...
    @typing.overload
    def setPixels(self, int: int, int2: int, int3: int, int4: int, floatArray: typing.List[float], dataBuffer: DataBuffer) -> None: ...
    @typing.overload
    def setPixels(self, int: int, int2: int, int3: int, int4: int, intArray: typing.List[int], dataBuffer: DataBuffer) -> None: ...
    @typing.overload
    def setSample(self, int: int, int2: int, int3: int, int4: int, dataBuffer: DataBuffer) -> None: ...
    @typing.overload
    def setSample(self, int: int, int2: int, int3: int, double: float, dataBuffer: DataBuffer) -> None: ...
    @typing.overload
    def setSample(self, int: int, int2: int, int3: int, float: float, dataBuffer: DataBuffer) -> None: ...
    @typing.overload
    def setSamples(self, int: int, int2: int, int3: int, int4: int, int5: int, doubleArray: typing.List[float], dataBuffer: DataBuffer) -> None: ...
    @typing.overload
    def setSamples(self, int: int, int2: int, int3: int, int4: int, int5: int, floatArray: typing.List[float], dataBuffer: DataBuffer) -> None: ...
    @typing.overload
    def setSamples(self, int: int, int2: int, int3: int, int4: int, int5: int, intArray: typing.List[int], dataBuffer: DataBuffer) -> None: ...

class TileObserver:
    def tileUpdate(self, writableRenderedImage: 'WritableRenderedImage', int: int, int2: int, boolean: bool) -> None: ...

class VolatileImage(java.awt.Image, java.awt.Transparency):
    IMAGE_OK: typing.ClassVar[int] = ...
    IMAGE_RESTORED: typing.ClassVar[int] = ...
    IMAGE_INCOMPATIBLE: typing.ClassVar[int] = ...
    def __init__(self): ...
    def contentsLost(self) -> bool: ...
    def createGraphics(self) -> java.awt.Graphics2D: ...
    @typing.overload
    def getCapabilities(self) -> java.awt.ImageCapabilities: ...
    @typing.overload
    def getCapabilities(self, graphicsConfiguration: java.awt.GraphicsConfiguration) -> java.awt.ImageCapabilities: ...
    def getGraphics(self) -> java.awt.Graphics: ...
    @typing.overload
    def getHeight(self, imageObserver: ImageObserver) -> int: ...
    @typing.overload
    def getHeight(self) -> int: ...
    def getSnapshot(self) -> 'BufferedImage': ...
    def getSource(self) -> ImageProducer: ...
    def getTransparency(self) -> int: ...
    @typing.overload
    def getWidth(self, imageObserver: ImageObserver) -> int: ...
    @typing.overload
    def getWidth(self) -> int: ...
    def validate(self, graphicsConfiguration: java.awt.GraphicsConfiguration) -> int: ...

class AbstractMultiResolutionImage(java.awt.Image, MultiResolutionImage):
    def __init__(self): ...
    def getGraphics(self) -> java.awt.Graphics: ...
    def getHeight(self, imageObserver: ImageObserver) -> int: ...
    def getProperty(self, string: str, imageObserver: ImageObserver) -> typing.Any: ...
    def getSource(self) -> ImageProducer: ...
    def getWidth(self, imageObserver: ImageObserver) -> int: ...

class AffineTransformOp(BufferedImageOp, RasterOp):
    TYPE_NEAREST_NEIGHBOR: typing.ClassVar[int] = ...
    TYPE_BILINEAR: typing.ClassVar[int] = ...
    TYPE_BICUBIC: typing.ClassVar[int] = ...
    @typing.overload
    def __init__(self, affineTransform: java.awt.geom.AffineTransform, int: int): ...
    @typing.overload
    def __init__(self, affineTransform: java.awt.geom.AffineTransform, renderingHints: java.awt.RenderingHints): ...
    def createCompatibleDestImage(self, bufferedImage: 'BufferedImage', colorModel: ColorModel) -> 'BufferedImage': ...
    def createCompatibleDestRaster(self, raster: Raster) -> 'WritableRaster': ...
    @typing.overload
    def filter(self, bufferedImage: 'BufferedImage', bufferedImage2: 'BufferedImage') -> 'BufferedImage': ...
    @typing.overload
    def filter(self, raster: Raster, writableRaster: 'WritableRaster') -> 'WritableRaster': ...
    @typing.overload
    def getBounds2D(self, bufferedImage: 'BufferedImage') -> java.awt.geom.Rectangle2D: ...
    @typing.overload
    def getBounds2D(self, raster: Raster) -> java.awt.geom.Rectangle2D: ...
    def getInterpolationType(self) -> int: ...
    def getPoint2D(self, point2D: java.awt.geom.Point2D, point2D2: java.awt.geom.Point2D) -> java.awt.geom.Point2D: ...
    def getRenderingHints(self) -> java.awt.RenderingHints: ...
    def getTransform(self) -> java.awt.geom.AffineTransform: ...

class BandCombineOp(RasterOp):
    def __init__(self, floatArray: typing.List[typing.List[float]], renderingHints: java.awt.RenderingHints): ...
    def createCompatibleDestRaster(self, raster: Raster) -> 'WritableRaster': ...
    def filter(self, raster: Raster, writableRaster: 'WritableRaster') -> 'WritableRaster': ...
    def getBounds2D(self, raster: Raster) -> java.awt.geom.Rectangle2D: ...
    def getMatrix(self) -> typing.List[typing.List[float]]: ...
    def getPoint2D(self, point2D: java.awt.geom.Point2D, point2D2: java.awt.geom.Point2D) -> java.awt.geom.Point2D: ...
    def getRenderingHints(self) -> java.awt.RenderingHints: ...

class ByteLookupTable(LookupTable):
    @typing.overload
    def __init__(self, int: int, byteArray: typing.List[int]): ...
    @typing.overload
    def __init__(self, int: int, byteArray: typing.List[typing.List[int]]): ...
    def getTable(self) -> typing.List[typing.List[int]]: ...
    @typing.overload
    def lookupPixel(self, byteArray: typing.List[int], byteArray2: typing.List[int]) -> typing.List[int]: ...
    @typing.overload
    def lookupPixel(self, intArray: typing.List[int], intArray2: typing.List[int]) -> typing.List[int]: ...

class ColorConvertOp(BufferedImageOp, RasterOp):
    @typing.overload
    def __init__(self, renderingHints: java.awt.RenderingHints): ...
    @typing.overload
    def __init__(self, colorSpace: java.awt.color.ColorSpace, renderingHints: java.awt.RenderingHints): ...
    @typing.overload
    def __init__(self, colorSpace: java.awt.color.ColorSpace, colorSpace2: java.awt.color.ColorSpace, renderingHints: java.awt.RenderingHints): ...
    @typing.overload
    def __init__(self, iCC_ProfileArray: typing.List[java.awt.color.ICC_Profile], renderingHints: java.awt.RenderingHints): ...
    def createCompatibleDestImage(self, bufferedImage: 'BufferedImage', colorModel: ColorModel) -> 'BufferedImage': ...
    def createCompatibleDestRaster(self, raster: Raster) -> 'WritableRaster': ...
    @typing.overload
    def filter(self, bufferedImage: 'BufferedImage', bufferedImage2: 'BufferedImage') -> 'BufferedImage': ...
    @typing.overload
    def filter(self, raster: Raster, writableRaster: 'WritableRaster') -> 'WritableRaster': ...
    @typing.overload
    def getBounds2D(self, bufferedImage: 'BufferedImage') -> java.awt.geom.Rectangle2D: ...
    @typing.overload
    def getBounds2D(self, raster: Raster) -> java.awt.geom.Rectangle2D: ...
    def getICC_Profiles(self) -> typing.List[java.awt.color.ICC_Profile]: ...
    def getPoint2D(self, point2D: java.awt.geom.Point2D, point2D2: java.awt.geom.Point2D) -> java.awt.geom.Point2D: ...
    def getRenderingHints(self) -> java.awt.RenderingHints: ...

class ComponentColorModel(ColorModel):
    @typing.overload
    def __init__(self, colorSpace: java.awt.color.ColorSpace, boolean: bool, boolean2: bool, int: int, int2: int): ...
    @typing.overload
    def __init__(self, colorSpace: java.awt.color.ColorSpace, intArray: typing.List[int], boolean: bool, boolean2: bool, int2: int, int3: int): ...
    def coerceData(self, writableRaster: 'WritableRaster', boolean: bool) -> ColorModel: ...
    def createCompatibleSampleModel(self, int: int, int2: int) -> SampleModel: ...
    def createCompatibleWritableRaster(self, int: int, int2: int) -> 'WritableRaster': ...
    def equals(self, object: typing.Any) -> bool: ...
    @typing.overload
    def getAlpha(self, int: int) -> int: ...
    @typing.overload
    def getAlpha(self, object: typing.Any) -> int: ...
    def getAlphaRaster(self, writableRaster: 'WritableRaster') -> 'WritableRaster': ...
    @typing.overload
    def getBlue(self, int: int) -> int: ...
    @typing.overload
    def getBlue(self, object: typing.Any) -> int: ...
    @typing.overload
    def getComponents(self, int: int, intArray: typing.List[int], int3: int) -> typing.List[int]: ...
    @typing.overload
    def getComponents(self, object: typing.Any, intArray: typing.List[int], int2: int) -> typing.List[int]: ...
    @typing.overload
    def getDataElement(self, floatArray: typing.List[float], int: int) -> int: ...
    @typing.overload
    def getDataElement(self, intArray: typing.List[int], int2: int) -> int: ...
    @typing.overload
    def getDataElements(self, floatArray: typing.List[float], int: int, object: typing.Any) -> typing.Any: ...
    @typing.overload
    def getDataElements(self, int: int, object: typing.Any) -> typing.Any: ...
    @typing.overload
    def getDataElements(self, intArray: typing.List[int], int2: int, object: typing.Any) -> typing.Any: ...
    @typing.overload
    def getGreen(self, int: int) -> int: ...
    @typing.overload
    def getGreen(self, object: typing.Any) -> int: ...
    @typing.overload
    def getNormalizedComponents(self, intArray: typing.List[int], int2: int, floatArray: typing.List[float], int3: int) -> typing.List[float]: ...
    @typing.overload
    def getNormalizedComponents(self, object: typing.Any, floatArray: typing.List[float], int: int) -> typing.List[float]: ...
    @typing.overload
    def getRGB(self, int: int) -> int: ...
    @typing.overload
    def getRGB(self, object: typing.Any) -> int: ...
    @typing.overload
    def getRed(self, int: int) -> int: ...
    @typing.overload
    def getRed(self, object: typing.Any) -> int: ...
    def getUnnormalizedComponents(self, floatArray: typing.List[float], int: int, intArray: typing.List[int], int3: int) -> typing.List[int]: ...
    def hashCode(self) -> int: ...
    def isCompatibleRaster(self, raster: Raster) -> bool: ...
    def isCompatibleSampleModel(self, sampleModel: SampleModel) -> bool: ...

class ComponentSampleModel(SampleModel):
    @typing.overload
    def __init__(self, int: int, int2: int, int3: int, int4: int, int5: int, intArray: typing.List[int]): ...
    @typing.overload
    def __init__(self, int: int, int2: int, int3: int, int4: int, int5: int, intArray: typing.List[int], intArray2: typing.List[int]): ...
    def createCompatibleSampleModel(self, int: int, int2: int) -> SampleModel: ...
    def createDataBuffer(self) -> DataBuffer: ...
    def createSubsetSampleModel(self, intArray: typing.List[int]) -> SampleModel: ...
    def equals(self, object: typing.Any) -> bool: ...
    def getBandOffsets(self) -> typing.List[int]: ...
    def getBankIndices(self) -> typing.List[int]: ...
    @typing.overload
    def getDataElements(self, int: int, int2: int, object: typing.Any, dataBuffer: DataBuffer) -> typing.Any: ...
    @typing.overload
    def getDataElements(self, int: int, int2: int, int3: int, int4: int, object: typing.Any, dataBuffer: DataBuffer) -> typing.Any: ...
    def getNumDataElements(self) -> int: ...
    @typing.overload
    def getOffset(self, int: int, int2: int) -> int: ...
    @typing.overload
    def getOffset(self, int: int, int2: int, int3: int) -> int: ...
    @typing.overload
    def getPixel(self, int: int, int2: int, doubleArray: typing.List[float], dataBuffer: DataBuffer) -> typing.List[float]: ...
    @typing.overload
    def getPixel(self, int: int, int2: int, floatArray: typing.List[float], dataBuffer: DataBuffer) -> typing.List[float]: ...
    @typing.overload
    def getPixel(self, int: int, int2: int, intArray: typing.List[int], dataBuffer: DataBuffer) -> typing.List[int]: ...
    def getPixelStride(self) -> int: ...
    @typing.overload
    def getPixels(self, int: int, int2: int, int3: int, int4: int, doubleArray: typing.List[float], dataBuffer: DataBuffer) -> typing.List[float]: ...
    @typing.overload
    def getPixels(self, int: int, int2: int, int3: int, int4: int, floatArray: typing.List[float], dataBuffer: DataBuffer) -> typing.List[float]: ...
    @typing.overload
    def getPixels(self, int: int, int2: int, int3: int, int4: int, intArray: typing.List[int], dataBuffer: DataBuffer) -> typing.List[int]: ...
    def getSample(self, int: int, int2: int, int3: int, dataBuffer: DataBuffer) -> int: ...
    def getSampleDouble(self, int: int, int2: int, int3: int, dataBuffer: DataBuffer) -> float: ...
    def getSampleFloat(self, int: int, int2: int, int3: int, dataBuffer: DataBuffer) -> float: ...
    @typing.overload
    def getSampleSize(self, int: int) -> int: ...
    @typing.overload
    def getSampleSize(self) -> typing.List[int]: ...
    @typing.overload
    def getSamples(self, int: int, int2: int, int3: int, int4: int, int5: int, doubleArray: typing.List[float], dataBuffer: DataBuffer) -> typing.List[float]: ...
    @typing.overload
    def getSamples(self, int: int, int2: int, int3: int, int4: int, int5: int, floatArray: typing.List[float], dataBuffer: DataBuffer) -> typing.List[float]: ...
    @typing.overload
    def getSamples(self, int: int, int2: int, int3: int, int4: int, int5: int, intArray: typing.List[int], dataBuffer: DataBuffer) -> typing.List[int]: ...
    def getScanlineStride(self) -> int: ...
    def hashCode(self) -> int: ...
    @typing.overload
    def setDataElements(self, int: int, int2: int, object: typing.Any, dataBuffer: DataBuffer) -> None: ...
    @typing.overload
    def setDataElements(self, int: int, int2: int, int3: int, int4: int, object: typing.Any, dataBuffer: DataBuffer) -> None: ...
    @typing.overload
    def setPixel(self, int: int, int2: int, intArray: typing.List[int], dataBuffer: DataBuffer) -> None: ...
    @typing.overload
    def setPixel(self, int: int, int2: int, doubleArray: typing.List[float], dataBuffer: DataBuffer) -> None: ...
    @typing.overload
    def setPixel(self, int: int, int2: int, floatArray: typing.List[float], dataBuffer: DataBuffer) -> None: ...
    @typing.overload
    def setPixels(self, int: int, int2: int, int3: int, int4: int, intArray: typing.List[int], dataBuffer: DataBuffer) -> None: ...
    @typing.overload
    def setPixels(self, int: int, int2: int, int3: int, int4: int, doubleArray: typing.List[float], dataBuffer: DataBuffer) -> None: ...
    @typing.overload
    def setPixels(self, int: int, int2: int, int3: int, int4: int, floatArray: typing.List[float], dataBuffer: DataBuffer) -> None: ...
    @typing.overload
    def setSample(self, int: int, int2: int, int3: int, double: float, dataBuffer: DataBuffer) -> None: ...
    @typing.overload
    def setSample(self, int: int, int2: int, int3: int, float: float, dataBuffer: DataBuffer) -> None: ...
    @typing.overload
    def setSample(self, int: int, int2: int, int3: int, int4: int, dataBuffer: DataBuffer) -> None: ...
    @typing.overload
    def setSamples(self, int: int, int2: int, int3: int, int4: int, int5: int, intArray: typing.List[int], dataBuffer: DataBuffer) -> None: ...
    @typing.overload
    def setSamples(self, int: int, int2: int, int3: int, int4: int, int5: int, doubleArray: typing.List[float], dataBuffer: DataBuffer) -> None: ...
    @typing.overload
    def setSamples(self, int: int, int2: int, int3: int, int4: int, int5: int, floatArray: typing.List[float], dataBuffer: DataBuffer) -> None: ...

class ConvolveOp(BufferedImageOp, RasterOp):
    EDGE_ZERO_FILL: typing.ClassVar[int] = ...
    EDGE_NO_OP: typing.ClassVar[int] = ...
    @typing.overload
    def __init__(self, kernel: Kernel): ...
    @typing.overload
    def __init__(self, kernel: Kernel, int: int, renderingHints: java.awt.RenderingHints): ...
    def createCompatibleDestImage(self, bufferedImage: 'BufferedImage', colorModel: ColorModel) -> 'BufferedImage': ...
    def createCompatibleDestRaster(self, raster: Raster) -> 'WritableRaster': ...
    @typing.overload
    def filter(self, bufferedImage: 'BufferedImage', bufferedImage2: 'BufferedImage') -> 'BufferedImage': ...
    @typing.overload
    def filter(self, raster: Raster, writableRaster: 'WritableRaster') -> 'WritableRaster': ...
    @typing.overload
    def getBounds2D(self, bufferedImage: 'BufferedImage') -> java.awt.geom.Rectangle2D: ...
    @typing.overload
    def getBounds2D(self, raster: Raster) -> java.awt.geom.Rectangle2D: ...
    def getEdgeCondition(self) -> int: ...
    def getKernel(self) -> Kernel: ...
    def getPoint2D(self, point2D: java.awt.geom.Point2D, point2D2: java.awt.geom.Point2D) -> java.awt.geom.Point2D: ...
    def getRenderingHints(self) -> java.awt.RenderingHints: ...

class DataBufferByte(DataBuffer):
    @typing.overload
    def __init__(self, byteArray: typing.List[int], int: int): ...
    @typing.overload
    def __init__(self, byteArray: typing.List[int], int: int, int2: int): ...
    @typing.overload
    def __init__(self, byteArray: typing.List[typing.List[int]], int: int): ...
    @typing.overload
    def __init__(self, byteArray: typing.List[typing.List[int]], int: int, intArray: typing.List[int]): ...
    @typing.overload
    def __init__(self, int: int): ...
    @typing.overload
    def __init__(self, int: int, int2: int): ...
    def getBankData(self) -> typing.List[typing.List[int]]: ...
    @typing.overload
    def getData(self) -> typing.List[int]: ...
    @typing.overload
    def getData(self, int: int) -> typing.List[int]: ...
    @typing.overload
    def getElem(self, int: int) -> int: ...
    @typing.overload
    def getElem(self, int: int, int2: int) -> int: ...
    @typing.overload
    def setElem(self, int: int, int2: int) -> None: ...
    @typing.overload
    def setElem(self, int: int, int2: int, int3: int) -> None: ...

class DataBufferDouble(DataBuffer):
    @typing.overload
    def __init__(self, doubleArray: typing.List[float], int: int): ...
    @typing.overload
    def __init__(self, doubleArray: typing.List[float], int: int, int2: int): ...
    @typing.overload
    def __init__(self, doubleArray: typing.List[typing.List[float]], int: int): ...
    @typing.overload
    def __init__(self, doubleArray: typing.List[typing.List[float]], int: int, intArray: typing.List[int]): ...
    @typing.overload
    def __init__(self, int: int): ...
    @typing.overload
    def __init__(self, int: int, int2: int): ...
    def getBankData(self) -> typing.List[typing.List[float]]: ...
    @typing.overload
    def getData(self) -> typing.List[float]: ...
    @typing.overload
    def getData(self, int: int) -> typing.List[float]: ...
    @typing.overload
    def getElem(self, int: int) -> int: ...
    @typing.overload
    def getElem(self, int: int, int2: int) -> int: ...
    @typing.overload
    def getElemDouble(self, int: int) -> float: ...
    @typing.overload
    def getElemDouble(self, int: int, int2: int) -> float: ...
    @typing.overload
    def getElemFloat(self, int: int) -> float: ...
    @typing.overload
    def getElemFloat(self, int: int, int2: int) -> float: ...
    @typing.overload
    def setElem(self, int: int, int2: int) -> None: ...
    @typing.overload
    def setElem(self, int: int, int2: int, int3: int) -> None: ...
    @typing.overload
    def setElemDouble(self, int: int, double: float) -> None: ...
    @typing.overload
    def setElemDouble(self, int: int, int2: int, double: float) -> None: ...
    @typing.overload
    def setElemFloat(self, int: int, float: float) -> None: ...
    @typing.overload
    def setElemFloat(self, int: int, int2: int, float: float) -> None: ...

class DataBufferFloat(DataBuffer):
    @typing.overload
    def __init__(self, floatArray: typing.List[float], int: int): ...
    @typing.overload
    def __init__(self, floatArray: typing.List[float], int: int, int2: int): ...
    @typing.overload
    def __init__(self, floatArray: typing.List[typing.List[float]], int: int): ...
    @typing.overload
    def __init__(self, floatArray: typing.List[typing.List[float]], int: int, intArray: typing.List[int]): ...
    @typing.overload
    def __init__(self, int: int): ...
    @typing.overload
    def __init__(self, int: int, int2: int): ...
    def getBankData(self) -> typing.List[typing.List[float]]: ...
    @typing.overload
    def getData(self) -> typing.List[float]: ...
    @typing.overload
    def getData(self, int: int) -> typing.List[float]: ...
    @typing.overload
    def getElem(self, int: int) -> int: ...
    @typing.overload
    def getElem(self, int: int, int2: int) -> int: ...
    @typing.overload
    def getElemDouble(self, int: int) -> float: ...
    @typing.overload
    def getElemDouble(self, int: int, int2: int) -> float: ...
    @typing.overload
    def getElemFloat(self, int: int) -> float: ...
    @typing.overload
    def getElemFloat(self, int: int, int2: int) -> float: ...
    @typing.overload
    def setElem(self, int: int, int2: int) -> None: ...
    @typing.overload
    def setElem(self, int: int, int2: int, int3: int) -> None: ...
    @typing.overload
    def setElemDouble(self, int: int, double: float) -> None: ...
    @typing.overload
    def setElemDouble(self, int: int, int2: int, double: float) -> None: ...
    @typing.overload
    def setElemFloat(self, int: int, float: float) -> None: ...
    @typing.overload
    def setElemFloat(self, int: int, int2: int, float: float) -> None: ...

class DataBufferInt(DataBuffer):
    @typing.overload
    def __init__(self, int: int): ...
    @typing.overload
    def __init__(self, int: int, int2: int): ...
    @typing.overload
    def __init__(self, intArray: typing.List[int], int2: int): ...
    @typing.overload
    def __init__(self, intArray: typing.List[int], int2: int, int3: int): ...
    @typing.overload
    def __init__(self, intArray: typing.List[typing.List[int]], int2: int): ...
    @typing.overload
    def __init__(self, intArray: typing.List[typing.List[int]], int2: int, intArray2: typing.List[int]): ...
    def getBankData(self) -> typing.List[typing.List[int]]: ...
    @typing.overload
    def getData(self) -> typing.List[int]: ...
    @typing.overload
    def getData(self, int: int) -> typing.List[int]: ...
    @typing.overload
    def getElem(self, int: int) -> int: ...
    @typing.overload
    def getElem(self, int: int, int2: int) -> int: ...
    @typing.overload
    def setElem(self, int: int, int2: int) -> None: ...
    @typing.overload
    def setElem(self, int: int, int2: int, int3: int) -> None: ...

class DataBufferShort(DataBuffer):
    @typing.overload
    def __init__(self, int: int): ...
    @typing.overload
    def __init__(self, int: int, int2: int): ...
    @typing.overload
    def __init__(self, shortArray: typing.List[int], int: int): ...
    @typing.overload
    def __init__(self, shortArray: typing.List[int], int: int, int2: int): ...
    @typing.overload
    def __init__(self, shortArray: typing.List[typing.List[int]], int: int): ...
    @typing.overload
    def __init__(self, shortArray: typing.List[typing.List[int]], int: int, intArray: typing.List[int]): ...
    def getBankData(self) -> typing.List[typing.List[int]]: ...
    @typing.overload
    def getData(self) -> typing.List[int]: ...
    @typing.overload
    def getData(self, int: int) -> typing.List[int]: ...
    @typing.overload
    def getElem(self, int: int) -> int: ...
    @typing.overload
    def getElem(self, int: int, int2: int) -> int: ...
    @typing.overload
    def setElem(self, int: int, int2: int) -> None: ...
    @typing.overload
    def setElem(self, int: int, int2: int, int3: int) -> None: ...

class DataBufferUShort(DataBuffer):
    @typing.overload
    def __init__(self, int: int): ...
    @typing.overload
    def __init__(self, int: int, int2: int): ...
    @typing.overload
    def __init__(self, shortArray: typing.List[int], int: int): ...
    @typing.overload
    def __init__(self, shortArray: typing.List[int], int: int, int2: int): ...
    @typing.overload
    def __init__(self, shortArray: typing.List[typing.List[int]], int: int): ...
    @typing.overload
    def __init__(self, shortArray: typing.List[typing.List[int]], int: int, intArray: typing.List[int]): ...
    def getBankData(self) -> typing.List[typing.List[int]]: ...
    @typing.overload
    def getData(self) -> typing.List[int]: ...
    @typing.overload
    def getData(self, int: int) -> typing.List[int]: ...
    @typing.overload
    def getElem(self, int: int) -> int: ...
    @typing.overload
    def getElem(self, int: int, int2: int) -> int: ...
    @typing.overload
    def setElem(self, int: int, int2: int) -> None: ...
    @typing.overload
    def setElem(self, int: int, int2: int, int3: int) -> None: ...

class FilteredImageSource(ImageProducer):
    def __init__(self, imageProducer: ImageProducer, imageFilter: 'ImageFilter'): ...
    def addConsumer(self, imageConsumer: ImageConsumer) -> None: ...
    def isConsumer(self, imageConsumer: ImageConsumer) -> bool: ...
    def removeConsumer(self, imageConsumer: ImageConsumer) -> None: ...
    def requestTopDownLeftRightResend(self, imageConsumer: ImageConsumer) -> None: ...
    def startProduction(self, imageConsumer: ImageConsumer) -> None: ...

class ImageFilter(ImageConsumer, java.lang.Cloneable):
    def __init__(self): ...
    def clone(self) -> typing.Any: ...
    def getFilterInstance(self, imageConsumer: ImageConsumer) -> 'ImageFilter': ...
    def imageComplete(self, int: int) -> None: ...
    def resendTopDownLeftRight(self, imageProducer: ImageProducer) -> None: ...
    def setColorModel(self, colorModel: ColorModel) -> None: ...
    def setDimensions(self, int: int, int2: int) -> None: ...
    def setHints(self, int: int) -> None: ...
    @typing.overload
    def setPixels(self, int: int, int2: int, int3: int, int4: int, colorModel: ColorModel, byteArray: typing.List[int], int5: int, int6: int) -> None: ...
    @typing.overload
    def setPixels(self, int: int, int2: int, int3: int, int4: int, colorModel: ColorModel, intArray: typing.List[int], int6: int, int7: int) -> None: ...
    def setProperties(self, hashtable: java.util.Hashtable[typing.Any, typing.Any]) -> None: ...

class IndexColorModel(ColorModel):
    @typing.overload
    def __init__(self, int: int, int2: int, byteArray: typing.List[int], byteArray2: typing.List[int], byteArray3: typing.List[int]): ...
    @typing.overload
    def __init__(self, int: int, int2: int, byteArray: typing.List[int], byteArray2: typing.List[int], byteArray3: typing.List[int], byteArray4: typing.List[int]): ...
    @typing.overload
    def __init__(self, int: int, int2: int, byteArray: typing.List[int], byteArray2: typing.List[int], byteArray3: typing.List[int], int3: int): ...
    @typing.overload
    def __init__(self, int: int, int2: int, byteArray: typing.List[int], int3: int, boolean: bool): ...
    @typing.overload
    def __init__(self, int: int, int2: int, byteArray: typing.List[int], int3: int, boolean: bool, int4: int): ...
    @typing.overload
    def __init__(self, int: int, int2: int, intArray: typing.List[int], int4: int, boolean: bool, int5: int, int6: int): ...
    @typing.overload
    def __init__(self, int: int, int2: int, intArray: typing.List[int], int4: int, int5: int, bigInteger: java.math.BigInteger): ...
    def convertToIntDiscrete(self, raster: Raster, boolean: bool) -> 'BufferedImage': ...
    def createCompatibleSampleModel(self, int: int, int2: int) -> SampleModel: ...
    def createCompatibleWritableRaster(self, int: int, int2: int) -> 'WritableRaster': ...
    def equals(self, object: typing.Any) -> bool: ...
    def finalize(self) -> None: ...
    @typing.overload
    def getAlpha(self, int: int) -> int: ...
    @typing.overload
    def getAlpha(self, object: typing.Any) -> int: ...
    def getAlphas(self, byteArray: typing.List[int]) -> None: ...
    @typing.overload
    def getBlue(self, int: int) -> int: ...
    @typing.overload
    def getBlue(self, object: typing.Any) -> int: ...
    def getBlues(self, byteArray: typing.List[int]) -> None: ...
    @typing.overload
    def getComponentSize(self, int: int) -> int: ...
    @typing.overload
    def getComponentSize(self) -> typing.List[int]: ...
    @typing.overload
    def getComponents(self, int: int, intArray: typing.List[int], int3: int) -> typing.List[int]: ...
    @typing.overload
    def getComponents(self, object: typing.Any, intArray: typing.List[int], int2: int) -> typing.List[int]: ...
    @typing.overload
    def getDataElement(self, floatArray: typing.List[float], int: int) -> int: ...
    @typing.overload
    def getDataElement(self, intArray: typing.List[int], int2: int) -> int: ...
    @typing.overload
    def getDataElements(self, floatArray: typing.List[float], int: int, object: typing.Any) -> typing.Any: ...
    @typing.overload
    def getDataElements(self, intArray: typing.List[int], int2: int, object: typing.Any) -> typing.Any: ...
    @typing.overload
    def getDataElements(self, int: int, object: typing.Any) -> typing.Any: ...
    @typing.overload
    def getGreen(self, int: int) -> int: ...
    @typing.overload
    def getGreen(self, object: typing.Any) -> int: ...
    def getGreens(self, byteArray: typing.List[int]) -> None: ...
    def getMapSize(self) -> int: ...
    @typing.overload
    def getRGB(self, int: int) -> int: ...
    @typing.overload
    def getRGB(self, object: typing.Any) -> int: ...
    def getRGBs(self, intArray: typing.List[int]) -> None: ...
    @typing.overload
    def getRed(self, int: int) -> int: ...
    @typing.overload
    def getRed(self, object: typing.Any) -> int: ...
    def getReds(self, byteArray: typing.List[int]) -> None: ...
    def getTransparency(self) -> int: ...
    def getTransparentPixel(self) -> int: ...
    def getValidPixels(self) -> java.math.BigInteger: ...
    def hashCode(self) -> int: ...
    def isCompatibleRaster(self, raster: Raster) -> bool: ...
    def isCompatibleSampleModel(self, sampleModel: SampleModel) -> bool: ...
    @typing.overload
    def isValid(self) -> bool: ...
    @typing.overload
    def isValid(self, int: int) -> bool: ...
    def toString(self) -> str: ...

class LookupOp(BufferedImageOp, RasterOp):
    def __init__(self, lookupTable: LookupTable, renderingHints: java.awt.RenderingHints): ...
    def createCompatibleDestImage(self, bufferedImage: 'BufferedImage', colorModel: ColorModel) -> 'BufferedImage': ...
    def createCompatibleDestRaster(self, raster: Raster) -> 'WritableRaster': ...
    @typing.overload
    def filter(self, bufferedImage: 'BufferedImage', bufferedImage2: 'BufferedImage') -> 'BufferedImage': ...
    @typing.overload
    def filter(self, raster: Raster, writableRaster: 'WritableRaster') -> 'WritableRaster': ...
    @typing.overload
    def getBounds2D(self, bufferedImage: 'BufferedImage') -> java.awt.geom.Rectangle2D: ...
    @typing.overload
    def getBounds2D(self, raster: Raster) -> java.awt.geom.Rectangle2D: ...
    def getPoint2D(self, point2D: java.awt.geom.Point2D, point2D2: java.awt.geom.Point2D) -> java.awt.geom.Point2D: ...
    def getRenderingHints(self) -> java.awt.RenderingHints: ...
    def getTable(self) -> LookupTable: ...

class MemoryImageSource(ImageProducer):
    @typing.overload
    def __init__(self, int: int, int2: int, intArray: typing.List[int], int4: int, int5: int): ...
    @typing.overload
    def __init__(self, int: int, int2: int, intArray: typing.List[int], int4: int, int5: int, hashtable: java.util.Hashtable[typing.Any, typing.Any]): ...
    @typing.overload
    def __init__(self, int: int, int2: int, colorModel: ColorModel, byteArray: typing.List[int], int3: int, int4: int): ...
    @typing.overload
    def __init__(self, int: int, int2: int, colorModel: ColorModel, byteArray: typing.List[int], int3: int, int4: int, hashtable: java.util.Hashtable[typing.Any, typing.Any]): ...
    @typing.overload
    def __init__(self, int: int, int2: int, colorModel: ColorModel, intArray: typing.List[int], int4: int, int5: int): ...
    @typing.overload
    def __init__(self, int: int, int2: int, colorModel: ColorModel, intArray: typing.List[int], int4: int, int5: int, hashtable: java.util.Hashtable[typing.Any, typing.Any]): ...
    def addConsumer(self, imageConsumer: ImageConsumer) -> None: ...
    def isConsumer(self, imageConsumer: ImageConsumer) -> bool: ...
    @typing.overload
    def newPixels(self, byteArray: typing.List[int], colorModel: ColorModel, int: int, int2: int) -> None: ...
    @typing.overload
    def newPixels(self, int: int, int2: int, int3: int, int4: int) -> None: ...
    @typing.overload
    def newPixels(self, int: int, int2: int, int3: int, int4: int, boolean: bool) -> None: ...
    @typing.overload
    def newPixels(self, intArray: typing.List[int], colorModel: ColorModel, int2: int, int3: int) -> None: ...
    @typing.overload
    def newPixels(self) -> None: ...
    def removeConsumer(self, imageConsumer: ImageConsumer) -> None: ...
    def requestTopDownLeftRightResend(self, imageConsumer: ImageConsumer) -> None: ...
    def setAnimated(self, boolean: bool) -> None: ...
    def setFullBufferUpdates(self, boolean: bool) -> None: ...
    def startProduction(self, imageConsumer: ImageConsumer) -> None: ...

class MultiPixelPackedSampleModel(SampleModel):
    @typing.overload
    def __init__(self, int: int, int2: int, int3: int, int4: int): ...
    @typing.overload
    def __init__(self, int: int, int2: int, int3: int, int4: int, int5: int, int6: int): ...
    def createCompatibleSampleModel(self, int: int, int2: int) -> SampleModel: ...
    def createDataBuffer(self) -> DataBuffer: ...
    def createSubsetSampleModel(self, intArray: typing.List[int]) -> SampleModel: ...
    def equals(self, object: typing.Any) -> bool: ...
    def getBitOffset(self, int: int) -> int: ...
    def getDataBitOffset(self) -> int: ...
    @typing.overload
    def getDataElements(self, int: int, int2: int, object: typing.Any, dataBuffer: DataBuffer) -> typing.Any: ...
    @typing.overload
    def getDataElements(self, int: int, int2: int, int3: int, int4: int, object: typing.Any, dataBuffer: DataBuffer) -> typing.Any: ...
    def getNumDataElements(self) -> int: ...
    def getOffset(self, int: int, int2: int) -> int: ...
    @typing.overload
    def getPixel(self, int: int, int2: int, doubleArray: typing.List[float], dataBuffer: DataBuffer) -> typing.List[float]: ...
    @typing.overload
    def getPixel(self, int: int, int2: int, floatArray: typing.List[float], dataBuffer: DataBuffer) -> typing.List[float]: ...
    @typing.overload
    def getPixel(self, int: int, int2: int, intArray: typing.List[int], dataBuffer: DataBuffer) -> typing.List[int]: ...
    def getPixelBitStride(self) -> int: ...
    def getSample(self, int: int, int2: int, int3: int, dataBuffer: DataBuffer) -> int: ...
    @typing.overload
    def getSampleSize(self, int: int) -> int: ...
    @typing.overload
    def getSampleSize(self) -> typing.List[int]: ...
    def getScanlineStride(self) -> int: ...
    def getTransferType(self) -> int: ...
    def hashCode(self) -> int: ...
    @typing.overload
    def setDataElements(self, int: int, int2: int, object: typing.Any, dataBuffer: DataBuffer) -> None: ...
    @typing.overload
    def setDataElements(self, int: int, int2: int, int3: int, int4: int, object: typing.Any, dataBuffer: DataBuffer) -> None: ...
    @typing.overload
    def setPixel(self, int: int, int2: int, intArray: typing.List[int], dataBuffer: DataBuffer) -> None: ...
    @typing.overload
    def setPixel(self, int: int, int2: int, doubleArray: typing.List[float], dataBuffer: DataBuffer) -> None: ...
    @typing.overload
    def setPixel(self, int: int, int2: int, floatArray: typing.List[float], dataBuffer: DataBuffer) -> None: ...
    @typing.overload
    def setSample(self, int: int, int2: int, int3: int, int4: int, dataBuffer: DataBuffer) -> None: ...
    @typing.overload
    def setSample(self, int: int, int2: int, int3: int, double: float, dataBuffer: DataBuffer) -> None: ...
    @typing.overload
    def setSample(self, int: int, int2: int, int3: int, float: float, dataBuffer: DataBuffer) -> None: ...

class PackedColorModel(ColorModel):
    @typing.overload
    def __init__(self, colorSpace: java.awt.color.ColorSpace, int: int, int2: int, int3: int, int4: int, int5: int, boolean: bool, int6: int, int7: int): ...
    @typing.overload
    def __init__(self, colorSpace: java.awt.color.ColorSpace, int: int, intArray: typing.List[int], int3: int, boolean: bool, int4: int, int5: int): ...
    def createCompatibleSampleModel(self, int: int, int2: int) -> SampleModel: ...
    def equals(self, object: typing.Any) -> bool: ...
    def getAlphaRaster(self, writableRaster: 'WritableRaster') -> 'WritableRaster': ...
    def getMask(self, int: int) -> int: ...
    def getMasks(self) -> typing.List[int]: ...
    def hashCode(self) -> int: ...
    def isCompatibleSampleModel(self, sampleModel: SampleModel) -> bool: ...

class PixelGrabber(ImageConsumer):
    @typing.overload
    def __init__(self, image: java.awt.Image, int: int, int2: int, int3: int, int4: int, boolean: bool): ...
    @typing.overload
    def __init__(self, image: java.awt.Image, int: int, int2: int, int3: int, int4: int, intArray: typing.List[int], int6: int, int7: int): ...
    @typing.overload
    def __init__(self, imageProducer: ImageProducer, int: int, int2: int, int3: int, int4: int, intArray: typing.List[int], int6: int, int7: int): ...
    def abortGrabbing(self) -> None: ...
    def getColorModel(self) -> ColorModel: ...
    def getHeight(self) -> int: ...
    def getPixels(self) -> typing.Any: ...
    def getStatus(self) -> int: ...
    def getWidth(self) -> int: ...
    @typing.overload
    def grabPixels(self) -> bool: ...
    @typing.overload
    def grabPixels(self, long: int) -> bool: ...
    def imageComplete(self, int: int) -> None: ...
    def setColorModel(self, colorModel: ColorModel) -> None: ...
    def setDimensions(self, int: int, int2: int) -> None: ...
    def setHints(self, int: int) -> None: ...
    @typing.overload
    def setPixels(self, int: int, int2: int, int3: int, int4: int, colorModel: ColorModel, byteArray: typing.List[int], int5: int, int6: int) -> None: ...
    @typing.overload
    def setPixels(self, int: int, int2: int, int3: int, int4: int, colorModel: ColorModel, intArray: typing.List[int], int6: int, int7: int) -> None: ...
    def setProperties(self, hashtable: java.util.Hashtable[typing.Any, typing.Any]) -> None: ...
    def startGrabbing(self) -> None: ...
    def status(self) -> int: ...

class RescaleOp(BufferedImageOp, RasterOp):
    @typing.overload
    def __init__(self, float: float, float2: float, renderingHints: java.awt.RenderingHints): ...
    @typing.overload
    def __init__(self, floatArray: typing.List[float], floatArray2: typing.List[float], renderingHints: java.awt.RenderingHints): ...
    def createCompatibleDestImage(self, bufferedImage: 'BufferedImage', colorModel: ColorModel) -> 'BufferedImage': ...
    def createCompatibleDestRaster(self, raster: Raster) -> 'WritableRaster': ...
    @typing.overload
    def filter(self, bufferedImage: 'BufferedImage', bufferedImage2: 'BufferedImage') -> 'BufferedImage': ...
    @typing.overload
    def filter(self, raster: Raster, writableRaster: 'WritableRaster') -> 'WritableRaster': ...
    @typing.overload
    def getBounds2D(self, bufferedImage: 'BufferedImage') -> java.awt.geom.Rectangle2D: ...
    @typing.overload
    def getBounds2D(self, raster: Raster) -> java.awt.geom.Rectangle2D: ...
    def getNumFactors(self) -> int: ...
    def getOffsets(self, floatArray: typing.List[float]) -> typing.List[float]: ...
    def getPoint2D(self, point2D: java.awt.geom.Point2D, point2D2: java.awt.geom.Point2D) -> java.awt.geom.Point2D: ...
    def getRenderingHints(self) -> java.awt.RenderingHints: ...
    def getScaleFactors(self, floatArray: typing.List[float]) -> typing.List[float]: ...

class ShortLookupTable(LookupTable):
    @typing.overload
    def __init__(self, int: int, shortArray: typing.List[int]): ...
    @typing.overload
    def __init__(self, int: int, shortArray: typing.List[typing.List[int]]): ...
    def getTable(self) -> typing.List[typing.List[int]]: ...
    @typing.overload
    def lookupPixel(self, intArray: typing.List[int], intArray2: typing.List[int]) -> typing.List[int]: ...
    @typing.overload
    def lookupPixel(self, shortArray: typing.List[int], shortArray2: typing.List[int]) -> typing.List[int]: ...

class SinglePixelPackedSampleModel(SampleModel):
    @typing.overload
    def __init__(self, int: int, int2: int, int3: int, int4: int, intArray: typing.List[int]): ...
    @typing.overload
    def __init__(self, int: int, int2: int, int3: int, intArray: typing.List[int]): ...
    def createCompatibleSampleModel(self, int: int, int2: int) -> SampleModel: ...
    def createDataBuffer(self) -> DataBuffer: ...
    def createSubsetSampleModel(self, intArray: typing.List[int]) -> SampleModel: ...
    def equals(self, object: typing.Any) -> bool: ...
    def getBitMasks(self) -> typing.List[int]: ...
    def getBitOffsets(self) -> typing.List[int]: ...
    @typing.overload
    def getDataElements(self, int: int, int2: int, int3: int, int4: int, object: typing.Any, dataBuffer: DataBuffer) -> typing.Any: ...
    @typing.overload
    def getDataElements(self, int: int, int2: int, object: typing.Any, dataBuffer: DataBuffer) -> typing.Any: ...
    def getNumDataElements(self) -> int: ...
    def getOffset(self, int: int, int2: int) -> int: ...
    @typing.overload
    def getPixel(self, int: int, int2: int, doubleArray: typing.List[float], dataBuffer: DataBuffer) -> typing.List[float]: ...
    @typing.overload
    def getPixel(self, int: int, int2: int, floatArray: typing.List[float], dataBuffer: DataBuffer) -> typing.List[float]: ...
    @typing.overload
    def getPixel(self, int: int, int2: int, intArray: typing.List[int], dataBuffer: DataBuffer) -> typing.List[int]: ...
    @typing.overload
    def getPixels(self, int: int, int2: int, int3: int, int4: int, doubleArray: typing.List[float], dataBuffer: DataBuffer) -> typing.List[float]: ...
    @typing.overload
    def getPixels(self, int: int, int2: int, int3: int, int4: int, floatArray: typing.List[float], dataBuffer: DataBuffer) -> typing.List[float]: ...
    @typing.overload
    def getPixels(self, int: int, int2: int, int3: int, int4: int, intArray: typing.List[int], dataBuffer: DataBuffer) -> typing.List[int]: ...
    def getSample(self, int: int, int2: int, int3: int, dataBuffer: DataBuffer) -> int: ...
    @typing.overload
    def getSampleSize(self, int: int) -> int: ...
    @typing.overload
    def getSampleSize(self) -> typing.List[int]: ...
    @typing.overload
    def getSamples(self, int: int, int2: int, int3: int, int4: int, int5: int, doubleArray: typing.List[float], dataBuffer: DataBuffer) -> typing.List[float]: ...
    @typing.overload
    def getSamples(self, int: int, int2: int, int3: int, int4: int, int5: int, floatArray: typing.List[float], dataBuffer: DataBuffer) -> typing.List[float]: ...
    @typing.overload
    def getSamples(self, int: int, int2: int, int3: int, int4: int, int5: int, intArray: typing.List[int], dataBuffer: DataBuffer) -> typing.List[int]: ...
    def getScanlineStride(self) -> int: ...
    def hashCode(self) -> int: ...
    @typing.overload
    def setDataElements(self, int: int, int2: int, int3: int, int4: int, object: typing.Any, dataBuffer: DataBuffer) -> None: ...
    @typing.overload
    def setDataElements(self, int: int, int2: int, object: typing.Any, dataBuffer: DataBuffer) -> None: ...
    @typing.overload
    def setPixel(self, int: int, int2: int, doubleArray: typing.List[float], dataBuffer: DataBuffer) -> None: ...
    @typing.overload
    def setPixel(self, int: int, int2: int, floatArray: typing.List[float], dataBuffer: DataBuffer) -> None: ...
    @typing.overload
    def setPixel(self, int: int, int2: int, intArray: typing.List[int], dataBuffer: DataBuffer) -> None: ...
    @typing.overload
    def setPixels(self, int: int, int2: int, int3: int, int4: int, doubleArray: typing.List[float], dataBuffer: DataBuffer) -> None: ...
    @typing.overload
    def setPixels(self, int: int, int2: int, int3: int, int4: int, floatArray: typing.List[float], dataBuffer: DataBuffer) -> None: ...
    @typing.overload
    def setPixels(self, int: int, int2: int, int3: int, int4: int, intArray: typing.List[int], dataBuffer: DataBuffer) -> None: ...
    @typing.overload
    def setSample(self, int: int, int2: int, int3: int, double: float, dataBuffer: DataBuffer) -> None: ...
    @typing.overload
    def setSample(self, int: int, int2: int, int3: int, float: float, dataBuffer: DataBuffer) -> None: ...
    @typing.overload
    def setSample(self, int: int, int2: int, int3: int, int4: int, dataBuffer: DataBuffer) -> None: ...
    @typing.overload
    def setSamples(self, int: int, int2: int, int3: int, int4: int, int5: int, doubleArray: typing.List[float], dataBuffer: DataBuffer) -> None: ...
    @typing.overload
    def setSamples(self, int: int, int2: int, int3: int, int4: int, int5: int, floatArray: typing.List[float], dataBuffer: DataBuffer) -> None: ...
    @typing.overload
    def setSamples(self, int: int, int2: int, int3: int, int4: int, int5: int, intArray: typing.List[int], dataBuffer: DataBuffer) -> None: ...

class WritableRaster(Raster):
    def createWritableChild(self, int: int, int2: int, int3: int, int4: int, int5: int, int6: int, intArray: typing.List[int]) -> 'WritableRaster': ...
    def createWritableTranslatedChild(self, int: int, int2: int) -> 'WritableRaster': ...
    def getWritableParent(self) -> 'WritableRaster': ...
    @typing.overload
    def setDataElements(self, int: int, int2: int, int3: int, int4: int, object: typing.Any) -> None: ...
    @typing.overload
    def setDataElements(self, int: int, int2: int, raster: Raster) -> None: ...
    @typing.overload
    def setDataElements(self, int: int, int2: int, object: typing.Any) -> None: ...
    @typing.overload
    def setPixel(self, int: int, int2: int, doubleArray: typing.List[float]) -> None: ...
    @typing.overload
    def setPixel(self, int: int, int2: int, floatArray: typing.List[float]) -> None: ...
    @typing.overload
    def setPixel(self, int: int, int2: int, intArray: typing.List[int]) -> None: ...
    @typing.overload
    def setPixels(self, int: int, int2: int, int3: int, int4: int, doubleArray: typing.List[float]) -> None: ...
    @typing.overload
    def setPixels(self, int: int, int2: int, int3: int, int4: int, floatArray: typing.List[float]) -> None: ...
    @typing.overload
    def setPixels(self, int: int, int2: int, int3: int, int4: int, intArray: typing.List[int]) -> None: ...
    @typing.overload
    def setRect(self, int: int, int2: int, raster: Raster) -> None: ...
    @typing.overload
    def setRect(self, raster: Raster) -> None: ...
    @typing.overload
    def setSample(self, int: int, int2: int, int3: int, double: float) -> None: ...
    @typing.overload
    def setSample(self, int: int, int2: int, int3: int, float: float) -> None: ...
    @typing.overload
    def setSample(self, int: int, int2: int, int3: int, int4: int) -> None: ...
    @typing.overload
    def setSamples(self, int: int, int2: int, int3: int, int4: int, int5: int, doubleArray: typing.List[float]) -> None: ...
    @typing.overload
    def setSamples(self, int: int, int2: int, int3: int, int4: int, int5: int, floatArray: typing.List[float]) -> None: ...
    @typing.overload
    def setSamples(self, int: int, int2: int, int3: int, int4: int, int5: int, intArray: typing.List[int]) -> None: ...

class WritableRenderedImage(RenderedImage):
    def addTileObserver(self, tileObserver: TileObserver) -> None: ...
    def getWritableTile(self, int: int, int2: int) -> WritableRaster: ...
    def getWritableTileIndices(self) -> typing.List[java.awt.Point]: ...
    def hasTileWriters(self) -> bool: ...
    def isTileWritable(self, int: int, int2: int) -> bool: ...
    def releaseWritableTile(self, int: int, int2: int) -> None: ...
    def removeTileObserver(self, tileObserver: TileObserver) -> None: ...
    def setData(self, raster: Raster) -> None: ...

class BandedSampleModel(ComponentSampleModel):
    @typing.overload
    def __init__(self, int: int, int2: int, int3: int, int4: int): ...
    @typing.overload
    def __init__(self, int: int, int2: int, int3: int, int4: int, intArray: typing.List[int], intArray2: typing.List[int]): ...
    def createCompatibleSampleModel(self, int: int, int2: int) -> SampleModel: ...
    def createDataBuffer(self) -> DataBuffer: ...
    def createSubsetSampleModel(self, intArray: typing.List[int]) -> SampleModel: ...
    @typing.overload
    def getDataElements(self, int: int, int2: int, object: typing.Any, dataBuffer: DataBuffer) -> typing.Any: ...
    @typing.overload
    def getDataElements(self, int: int, int2: int, int3: int, int4: int, object: typing.Any, dataBuffer: DataBuffer) -> typing.Any: ...
    @typing.overload
    def getPixel(self, int: int, int2: int, doubleArray: typing.List[float], dataBuffer: DataBuffer) -> typing.List[float]: ...
    @typing.overload
    def getPixel(self, int: int, int2: int, floatArray: typing.List[float], dataBuffer: DataBuffer) -> typing.List[float]: ...
    @typing.overload
    def getPixel(self, int: int, int2: int, intArray: typing.List[int], dataBuffer: DataBuffer) -> typing.List[int]: ...
    @typing.overload
    def getPixels(self, int: int, int2: int, int3: int, int4: int, doubleArray: typing.List[float], dataBuffer: DataBuffer) -> typing.List[float]: ...
    @typing.overload
    def getPixels(self, int: int, int2: int, int3: int, int4: int, floatArray: typing.List[float], dataBuffer: DataBuffer) -> typing.List[float]: ...
    @typing.overload
    def getPixels(self, int: int, int2: int, int3: int, int4: int, intArray: typing.List[int], dataBuffer: DataBuffer) -> typing.List[int]: ...
    def getSample(self, int: int, int2: int, int3: int, dataBuffer: DataBuffer) -> int: ...
    def getSampleDouble(self, int: int, int2: int, int3: int, dataBuffer: DataBuffer) -> float: ...
    def getSampleFloat(self, int: int, int2: int, int3: int, dataBuffer: DataBuffer) -> float: ...
    @typing.overload
    def getSamples(self, int: int, int2: int, int3: int, int4: int, int5: int, doubleArray: typing.List[float], dataBuffer: DataBuffer) -> typing.List[float]: ...
    @typing.overload
    def getSamples(self, int: int, int2: int, int3: int, int4: int, int5: int, floatArray: typing.List[float], dataBuffer: DataBuffer) -> typing.List[float]: ...
    @typing.overload
    def getSamples(self, int: int, int2: int, int3: int, int4: int, int5: int, intArray: typing.List[int], dataBuffer: DataBuffer) -> typing.List[int]: ...
    def hashCode(self) -> int: ...
    @typing.overload
    def setDataElements(self, int: int, int2: int, object: typing.Any, dataBuffer: DataBuffer) -> None: ...
    @typing.overload
    def setDataElements(self, int: int, int2: int, int3: int, int4: int, object: typing.Any, dataBuffer: DataBuffer) -> None: ...
    @typing.overload
    def setPixel(self, int: int, int2: int, intArray: typing.List[int], dataBuffer: DataBuffer) -> None: ...
    @typing.overload
    def setPixel(self, int: int, int2: int, doubleArray: typing.List[float], dataBuffer: DataBuffer) -> None: ...
    @typing.overload
    def setPixel(self, int: int, int2: int, floatArray: typing.List[float], dataBuffer: DataBuffer) -> None: ...
    @typing.overload
    def setPixels(self, int: int, int2: int, int3: int, int4: int, intArray: typing.List[int], dataBuffer: DataBuffer) -> None: ...
    @typing.overload
    def setPixels(self, int: int, int2: int, int3: int, int4: int, doubleArray: typing.List[float], dataBuffer: DataBuffer) -> None: ...
    @typing.overload
    def setPixels(self, int: int, int2: int, int3: int, int4: int, floatArray: typing.List[float], dataBuffer: DataBuffer) -> None: ...
    @typing.overload
    def setSample(self, int: int, int2: int, int3: int, double: float, dataBuffer: DataBuffer) -> None: ...
    @typing.overload
    def setSample(self, int: int, int2: int, int3: int, float: float, dataBuffer: DataBuffer) -> None: ...
    @typing.overload
    def setSample(self, int: int, int2: int, int3: int, int4: int, dataBuffer: DataBuffer) -> None: ...
    @typing.overload
    def setSamples(self, int: int, int2: int, int3: int, int4: int, int5: int, intArray: typing.List[int], dataBuffer: DataBuffer) -> None: ...
    @typing.overload
    def setSamples(self, int: int, int2: int, int3: int, int4: int, int5: int, doubleArray: typing.List[float], dataBuffer: DataBuffer) -> None: ...
    @typing.overload
    def setSamples(self, int: int, int2: int, int3: int, int4: int, int5: int, floatArray: typing.List[float], dataBuffer: DataBuffer) -> None: ...

class BaseMultiResolutionImage(AbstractMultiResolutionImage):
    @typing.overload
    def __init__(self, int: int, imageArray: typing.List[java.awt.Image]): ...
    @typing.overload
    def __init__(self, imageArray: typing.List[java.awt.Image]): ...
    def getResolutionVariant(self, double: float, double2: float) -> java.awt.Image: ...
    def getResolutionVariants(self) -> java.util.List[java.awt.Image]: ...

class BufferedImage(java.awt.Image, WritableRenderedImage, java.awt.Transparency):
    TYPE_CUSTOM: typing.ClassVar[int] = ...
    TYPE_INT_RGB: typing.ClassVar[int] = ...
    TYPE_INT_ARGB: typing.ClassVar[int] = ...
    TYPE_INT_ARGB_PRE: typing.ClassVar[int] = ...
    TYPE_INT_BGR: typing.ClassVar[int] = ...
    TYPE_3BYTE_BGR: typing.ClassVar[int] = ...
    TYPE_4BYTE_ABGR: typing.ClassVar[int] = ...
    TYPE_4BYTE_ABGR_PRE: typing.ClassVar[int] = ...
    TYPE_USHORT_565_RGB: typing.ClassVar[int] = ...
    TYPE_USHORT_555_RGB: typing.ClassVar[int] = ...
    TYPE_BYTE_GRAY: typing.ClassVar[int] = ...
    TYPE_USHORT_GRAY: typing.ClassVar[int] = ...
    TYPE_BYTE_BINARY: typing.ClassVar[int] = ...
    TYPE_BYTE_INDEXED: typing.ClassVar[int] = ...
    @typing.overload
    def __init__(self, int: int, int2: int, int3: int): ...
    @typing.overload
    def __init__(self, int: int, int2: int, int3: int, indexColorModel: IndexColorModel): ...
    @typing.overload
    def __init__(self, colorModel: ColorModel, writableRaster: WritableRaster, boolean: bool, hashtable: java.util.Hashtable[typing.Any, typing.Any]): ...
    def addTileObserver(self, tileObserver: TileObserver) -> None: ...
    def coerceData(self, boolean: bool) -> None: ...
    def copyData(self, writableRaster: WritableRaster) -> WritableRaster: ...
    def createGraphics(self) -> java.awt.Graphics2D: ...
    def getAlphaRaster(self) -> WritableRaster: ...
    def getColorModel(self) -> ColorModel: ...
    @typing.overload
    def getData(self) -> Raster: ...
    @typing.overload
    def getData(self, rectangle: java.awt.Rectangle) -> Raster: ...
    def getGraphics(self) -> java.awt.Graphics: ...
    @typing.overload
    def getHeight(self) -> int: ...
    @typing.overload
    def getHeight(self, imageObserver: ImageObserver) -> int: ...
    def getMinTileX(self) -> int: ...
    def getMinTileY(self) -> int: ...
    def getMinX(self) -> int: ...
    def getMinY(self) -> int: ...
    def getNumXTiles(self) -> int: ...
    def getNumYTiles(self) -> int: ...
    @typing.overload
    def getProperty(self, string: str) -> typing.Any: ...
    @typing.overload
    def getProperty(self, string: str, imageObserver: ImageObserver) -> typing.Any: ...
    def getPropertyNames(self) -> typing.List[str]: ...
    @typing.overload
    def getRGB(self, int: int, int2: int) -> int: ...
    @typing.overload
    def getRGB(self, int: int, int2: int, int3: int, int4: int, intArray: typing.List[int], int6: int, int7: int) -> typing.List[int]: ...
    def getRaster(self) -> WritableRaster: ...
    def getSampleModel(self) -> SampleModel: ...
    def getSource(self) -> ImageProducer: ...
    def getSources(self) -> java.util.Vector[RenderedImage]: ...
    def getSubimage(self, int: int, int2: int, int3: int, int4: int) -> 'BufferedImage': ...
    def getTile(self, int: int, int2: int) -> Raster: ...
    def getTileGridXOffset(self) -> int: ...
    def getTileGridYOffset(self) -> int: ...
    def getTileHeight(self) -> int: ...
    def getTileWidth(self) -> int: ...
    def getTransparency(self) -> int: ...
    def getType(self) -> int: ...
    @typing.overload
    def getWidth(self) -> int: ...
    @typing.overload
    def getWidth(self, imageObserver: ImageObserver) -> int: ...
    def getWritableTile(self, int: int, int2: int) -> WritableRaster: ...
    def getWritableTileIndices(self) -> typing.List[java.awt.Point]: ...
    def hasTileWriters(self) -> bool: ...
    def isAlphaPremultiplied(self) -> bool: ...
    def isTileWritable(self, int: int, int2: int) -> bool: ...
    def releaseWritableTile(self, int: int, int2: int) -> None: ...
    def removeTileObserver(self, tileObserver: TileObserver) -> None: ...
    def setData(self, raster: Raster) -> None: ...
    @typing.overload
    def setRGB(self, int: int, int2: int, int3: int) -> None: ...
    @typing.overload
    def setRGB(self, int: int, int2: int, int3: int, int4: int, intArray: typing.List[int], int6: int, int7: int) -> None: ...
    def toString(self) -> str: ...

class BufferedImageFilter(ImageFilter, java.lang.Cloneable):
    def __init__(self, bufferedImageOp: BufferedImageOp): ...
    def getBufferedImageOp(self) -> BufferedImageOp: ...
    def imageComplete(self, int: int) -> None: ...
    def setColorModel(self, colorModel: ColorModel) -> None: ...
    def setDimensions(self, int: int, int2: int) -> None: ...
    @typing.overload
    def setPixels(self, int: int, int2: int, int3: int, int4: int, colorModel: ColorModel, byteArray: typing.List[int], int5: int, int6: int) -> None: ...
    @typing.overload
    def setPixels(self, int: int, int2: int, int3: int, int4: int, colorModel: ColorModel, intArray: typing.List[int], int6: int, int7: int) -> None: ...

class CropImageFilter(ImageFilter):
    def __init__(self, int: int, int2: int, int3: int, int4: int): ...
    def setDimensions(self, int: int, int2: int) -> None: ...
    @typing.overload
    def setPixels(self, int: int, int2: int, int3: int, int4: int, colorModel: ColorModel, byteArray: typing.List[int], int5: int, int6: int) -> None: ...
    @typing.overload
    def setPixels(self, int: int, int2: int, int3: int, int4: int, colorModel: ColorModel, intArray: typing.List[int], int6: int, int7: int) -> None: ...
    def setProperties(self, hashtable: java.util.Hashtable[typing.Any, typing.Any]) -> None: ...

class DirectColorModel(PackedColorModel):
    @typing.overload
    def __init__(self, int: int, int2: int, int3: int, int4: int): ...
    @typing.overload
    def __init__(self, int: int, int2: int, int3: int, int4: int, int5: int): ...
    @typing.overload
    def __init__(self, colorSpace: java.awt.color.ColorSpace, int: int, int2: int, int3: int, int4: int, int5: int, boolean: bool, int6: int): ...
    def coerceData(self, writableRaster: WritableRaster, boolean: bool) -> ColorModel: ...
    def createCompatibleWritableRaster(self, int: int, int2: int) -> WritableRaster: ...
    @typing.overload
    def getAlpha(self, int: int) -> int: ...
    @typing.overload
    def getAlpha(self, object: typing.Any) -> int: ...
    def getAlphaMask(self) -> int: ...
    @typing.overload
    def getBlue(self, int: int) -> int: ...
    @typing.overload
    def getBlue(self, object: typing.Any) -> int: ...
    def getBlueMask(self) -> int: ...
    @typing.overload
    def getComponents(self, int: int, intArray: typing.List[int], int3: int) -> typing.List[int]: ...
    @typing.overload
    def getComponents(self, object: typing.Any, intArray: typing.List[int], int2: int) -> typing.List[int]: ...
    @typing.overload
    def getDataElement(self, floatArray: typing.List[float], int: int) -> int: ...
    @typing.overload
    def getDataElement(self, intArray: typing.List[int], int2: int) -> int: ...
    @typing.overload
    def getDataElements(self, floatArray: typing.List[float], int: int, object: typing.Any) -> typing.Any: ...
    @typing.overload
    def getDataElements(self, int: int, object: typing.Any) -> typing.Any: ...
    @typing.overload
    def getDataElements(self, intArray: typing.List[int], int2: int, object: typing.Any) -> typing.Any: ...
    @typing.overload
    def getGreen(self, int: int) -> int: ...
    @typing.overload
    def getGreen(self, object: typing.Any) -> int: ...
    def getGreenMask(self) -> int: ...
    @typing.overload
    def getRGB(self, int: int) -> int: ...
    @typing.overload
    def getRGB(self, object: typing.Any) -> int: ...
    @typing.overload
    def getRed(self, int: int) -> int: ...
    @typing.overload
    def getRed(self, object: typing.Any) -> int: ...
    def getRedMask(self) -> int: ...
    def isCompatibleRaster(self, raster: Raster) -> bool: ...
    def toString(self) -> str: ...

class PixelInterleavedSampleModel(ComponentSampleModel):
    def __init__(self, int: int, int2: int, int3: int, int4: int, int5: int, intArray: typing.List[int]): ...
    def createCompatibleSampleModel(self, int: int, int2: int) -> SampleModel: ...
    def createSubsetSampleModel(self, intArray: typing.List[int]) -> SampleModel: ...
    def hashCode(self) -> int: ...

class RGBImageFilter(ImageFilter):
    def __init__(self): ...
    def filterIndexColorModel(self, indexColorModel: IndexColorModel) -> IndexColorModel: ...
    def filterRGB(self, int: int, int2: int, int3: int) -> int: ...
    def filterRGBPixels(self, int: int, int2: int, int3: int, int4: int, intArray: typing.List[int], int6: int, int7: int) -> None: ...
    def setColorModel(self, colorModel: ColorModel) -> None: ...
    @typing.overload
    def setPixels(self, int: int, int2: int, int3: int, int4: int, colorModel: ColorModel, byteArray: typing.List[int], int5: int, int6: int) -> None: ...
    @typing.overload
    def setPixels(self, int: int, int2: int, int3: int, int4: int, colorModel: ColorModel, intArray: typing.List[int], int6: int, int7: int) -> None: ...
    def substituteColorModel(self, colorModel: ColorModel, colorModel2: ColorModel) -> None: ...

class ReplicateScaleFilter(ImageFilter):
    def __init__(self, int: int, int2: int): ...
    def setDimensions(self, int: int, int2: int) -> None: ...
    @typing.overload
    def setPixels(self, int: int, int2: int, int3: int, int4: int, colorModel: ColorModel, byteArray: typing.List[int], int5: int, int6: int) -> None: ...
    @typing.overload
    def setPixels(self, int: int, int2: int, int3: int, int4: int, colorModel: ColorModel, intArray: typing.List[int], int6: int, int7: int) -> None: ...
    def setProperties(self, hashtable: java.util.Hashtable[typing.Any, typing.Any]) -> None: ...

class AreaAveragingScaleFilter(ReplicateScaleFilter):
    def __init__(self, int: int, int2: int): ...
    def setHints(self, int: int) -> None: ...
    @typing.overload
    def setPixels(self, int: int, int2: int, int3: int, int4: int, colorModel: ColorModel, byteArray: typing.List[int], int5: int, int6: int) -> None: ...
    @typing.overload
    def setPixels(self, int: int, int2: int, int3: int, int4: int, colorModel: ColorModel, intArray: typing.List[int], int6: int, int7: int) -> None: ...


class __module_protocol__(typing.Protocol):
    # A module protocol which reflects the result of ``jp.JPackage("java.awt.image")``.

    AbstractMultiResolutionImage: typing.Type[AbstractMultiResolutionImage]
    AffineTransformOp: typing.Type[AffineTransformOp]
    AreaAveragingScaleFilter: typing.Type[AreaAveragingScaleFilter]
    BandCombineOp: typing.Type[BandCombineOp]
    BandedSampleModel: typing.Type[BandedSampleModel]
    BaseMultiResolutionImage: typing.Type[BaseMultiResolutionImage]
    BufferStrategy: typing.Type[BufferStrategy]
    BufferedImage: typing.Type[BufferedImage]
    BufferedImageFilter: typing.Type[BufferedImageFilter]
    BufferedImageOp: typing.Type[BufferedImageOp]
    ByteLookupTable: typing.Type[ByteLookupTable]
    ColorConvertOp: typing.Type[ColorConvertOp]
    ColorModel: typing.Type[ColorModel]
    ComponentColorModel: typing.Type[ComponentColorModel]
    ComponentSampleModel: typing.Type[ComponentSampleModel]
    ConvolveOp: typing.Type[ConvolveOp]
    CropImageFilter: typing.Type[CropImageFilter]
    DataBuffer: typing.Type[DataBuffer]
    DataBufferByte: typing.Type[DataBufferByte]
    DataBufferDouble: typing.Type[DataBufferDouble]
    DataBufferFloat: typing.Type[DataBufferFloat]
    DataBufferInt: typing.Type[DataBufferInt]
    DataBufferShort: typing.Type[DataBufferShort]
    DataBufferUShort: typing.Type[DataBufferUShort]
    DirectColorModel: typing.Type[DirectColorModel]
    FilteredImageSource: typing.Type[FilteredImageSource]
    ImageConsumer: typing.Type[ImageConsumer]
    ImageFilter: typing.Type[ImageFilter]
    ImageObserver: typing.Type[ImageObserver]
    ImageProducer: typing.Type[ImageProducer]
    ImagingOpException: typing.Type[ImagingOpException]
    IndexColorModel: typing.Type[IndexColorModel]
    Kernel: typing.Type[Kernel]
    LookupOp: typing.Type[LookupOp]
    LookupTable: typing.Type[LookupTable]
    MemoryImageSource: typing.Type[MemoryImageSource]
    MultiPixelPackedSampleModel: typing.Type[MultiPixelPackedSampleModel]
    MultiResolutionImage: typing.Type[MultiResolutionImage]
    PackedColorModel: typing.Type[PackedColorModel]
    PixelGrabber: typing.Type[PixelGrabber]
    PixelInterleavedSampleModel: typing.Type[PixelInterleavedSampleModel]
    RGBImageFilter: typing.Type[RGBImageFilter]
    Raster: typing.Type[Raster]
    RasterFormatException: typing.Type[RasterFormatException]
    RasterOp: typing.Type[RasterOp]
    RenderedImage: typing.Type[RenderedImage]
    ReplicateScaleFilter: typing.Type[ReplicateScaleFilter]
    RescaleOp: typing.Type[RescaleOp]
    SampleModel: typing.Type[SampleModel]
    ShortLookupTable: typing.Type[ShortLookupTable]
    SinglePixelPackedSampleModel: typing.Type[SinglePixelPackedSampleModel]
    TileObserver: typing.Type[TileObserver]
    VolatileImage: typing.Type[VolatileImage]
    WritableRaster: typing.Type[WritableRaster]
    WritableRenderedImage: typing.Type[WritableRenderedImage]
    renderable: java.awt.image.renderable.__module_protocol__



import java.lang
import scala
import scala.collection
import sigmastate
import sigmastate.serialization
import sigmastate.utils
import typing



_QuadrupleSerializer__S1 = typing.TypeVar('_QuadrupleSerializer__S1', bound=sigmastate.SType)  # <S1>
_QuadrupleSerializer__S2 = typing.TypeVar('_QuadrupleSerializer__S2', bound=sigmastate.SType)  # <S2>
_QuadrupleSerializer__S3 = typing.TypeVar('_QuadrupleSerializer__S3', bound=sigmastate.SType)  # <S3>
_QuadrupleSerializer__S4 = typing.TypeVar('_QuadrupleSerializer__S4', bound=sigmastate.SType)  # <S4>
class QuadrupleSerializer(sigmastate.serialization.ValueSerializer[sigmastate.Quadruple[_QuadrupleSerializer__S1, _QuadrupleSerializer__S2, _QuadrupleSerializer__S3, _QuadrupleSerializer__S4]], scala.Product, scala.Serializable, typing.Generic[_QuadrupleSerializer__S1, _QuadrupleSerializer__S2, _QuadrupleSerializer__S3, _QuadrupleSerializer__S4]):
    def __init__(self, opDesc: sigmastate.QuadrupleCompanion, cons: scala.Function3[sigmastate.Values.Value[_QuadrupleSerializer__S1], sigmastate.Values.Value[_QuadrupleSerializer__S2], sigmastate.Values.Value[_QuadrupleSerializer__S3], sigmastate.Values.Value[_QuadrupleSerializer__S4]]): ...
    _apply__S1 = typing.TypeVar('_apply__S1', bound=sigmastate.SType)  # <S1>
    _apply__S2 = typing.TypeVar('_apply__S2', bound=sigmastate.SType)  # <S2>
    _apply__S3 = typing.TypeVar('_apply__S3', bound=sigmastate.SType)  # <S3>
    _apply__S4 = typing.TypeVar('_apply__S4', bound=sigmastate.SType)  # <S4>
    @staticmethod
    def apply(opDesc: sigmastate.QuadrupleCompanion, cons: scala.Function3[sigmastate.Values.Value[_apply__S1], sigmastate.Values.Value[_apply__S2], sigmastate.Values.Value[_apply__S3], sigmastate.Values.Value[_apply__S4]]) -> 'QuadrupleSerializer'[_apply__S1, _apply__S2, _apply__S3, _apply__S4]: ...
    def canEqual(self, x$1: typing.Any) -> bool: ...
    def cons(self) -> scala.Function3[sigmastate.Values.Value[_QuadrupleSerializer__S1], sigmastate.Values.Value[_QuadrupleSerializer__S2], sigmastate.Values.Value[_QuadrupleSerializer__S3], sigmastate.Values.Value[_QuadrupleSerializer__S4]]: ...
    _copy__S1 = typing.TypeVar('_copy__S1', bound=sigmastate.SType)  # <S1>
    _copy__S2 = typing.TypeVar('_copy__S2', bound=sigmastate.SType)  # <S2>
    _copy__S3 = typing.TypeVar('_copy__S3', bound=sigmastate.SType)  # <S3>
    _copy__S4 = typing.TypeVar('_copy__S4', bound=sigmastate.SType)  # <S4>
    def copy(self, opDesc: sigmastate.QuadrupleCompanion, cons: scala.Function3[sigmastate.Values.Value[sigmastate.SType], sigmastate.Values.Value[sigmastate.SType], sigmastate.Values.Value[sigmastate.SType], sigmastate.Values.Value[sigmastate.SType]]) -> 'QuadrupleSerializer'[sigmastate.SType, sigmastate.SType, sigmastate.SType, sigmastate.SType]: ...
    _copy$default$1__S1 = typing.TypeVar('_copy$default$1__S1', bound=sigmastate.SType)  # <S1>
    _copy$default$1__S2 = typing.TypeVar('_copy$default$1__S2', bound=sigmastate.SType)  # <S2>
    _copy$default$1__S3 = typing.TypeVar('_copy$default$1__S3', bound=sigmastate.SType)  # <S3>
    _copy$default$1__S4 = typing.TypeVar('_copy$default$1__S4', bound=sigmastate.SType)  # <S4>
    def copy$default$1(self) -> sigmastate.QuadrupleCompanion: ...
    _copy$default$2__S1 = typing.TypeVar('_copy$default$2__S1', bound=sigmastate.SType)  # <S1>
    _copy$default$2__S2 = typing.TypeVar('_copy$default$2__S2', bound=sigmastate.SType)  # <S2>
    _copy$default$2__S3 = typing.TypeVar('_copy$default$2__S3', bound=sigmastate.SType)  # <S3>
    _copy$default$2__S4 = typing.TypeVar('_copy$default$2__S4', bound=sigmastate.SType)  # <S4>
    def copy$default$2(self) -> scala.Function3[sigmastate.Values.Value[sigmastate.SType], sigmastate.Values.Value[sigmastate.SType], sigmastate.Values.Value[sigmastate.SType], sigmastate.Values.Value[sigmastate.SType]]: ...
    def equals(self, x$1: typing.Any) -> bool: ...
    def firstInfo(self) -> sigmastate.utils.SigmaByteWriter.DataInfo[sigmastate.Values.Value[sigmastate.SType]]: ...
    def hashCode(self) -> int: ...
    def opDesc(self) -> sigmastate.QuadrupleCompanion: ...
    def parse(self, r: sigmastate.utils.SigmaByteReader) -> sigmastate.Values.Value[_QuadrupleSerializer__S4]: ...
    def productArity(self) -> int: ...
    def productElement(self, x$1: int) -> typing.Any: ...
    def productIterator(self) -> scala.collection.Iterator[typing.Any]: ...
    def productPrefix(self) -> java.lang.String: ...
    def secondInfo(self) -> sigmastate.utils.SigmaByteWriter.DataInfo[sigmastate.Values.Value[sigmastate.SType]]: ...
    def serialize(self, obj: sigmastate.Quadruple[_QuadrupleSerializer__S1, _QuadrupleSerializer__S2, _QuadrupleSerializer__S3, _QuadrupleSerializer__S4], w: sigmastate.utils.SigmaByteWriter) -> None: ...
    def thirdInfo(self) -> sigmastate.utils.SigmaByteWriter.DataInfo[sigmastate.Values.Value[sigmastate.SType]]: ...
    def toString(self) -> java.lang.String: ...
    _unapply__S1 = typing.TypeVar('_unapply__S1', bound=sigmastate.SType)  # <S1>
    _unapply__S2 = typing.TypeVar('_unapply__S2', bound=sigmastate.SType)  # <S2>
    _unapply__S3 = typing.TypeVar('_unapply__S3', bound=sigmastate.SType)  # <S3>
    _unapply__S4 = typing.TypeVar('_unapply__S4', bound=sigmastate.SType)  # <S4>
    @staticmethod
    def unapply(x$0: 'QuadrupleSerializer'[_unapply__S1, _unapply__S2, _unapply__S3, _unapply__S4]) -> scala.Option[scala.Tuple2[sigmastate.QuadrupleCompanion, scala.Function3[sigmastate.Values.Value[_unapply__S1], sigmastate.Values.Value[_unapply__S2], sigmastate.Values.Value[_unapply__S3], sigmastate.Values.Value[_unapply__S4]]]]: ...

_Relation2Serializer__S1 = typing.TypeVar('_Relation2Serializer__S1', bound=sigmastate.SType)  # <S1>
_Relation2Serializer__S2 = typing.TypeVar('_Relation2Serializer__S2', bound=sigmastate.SType)  # <S2>
_Relation2Serializer__R = typing.TypeVar('_Relation2Serializer__R', bound=sigmastate.Values.Value)  # <R>
class Relation2Serializer(sigmastate.serialization.ValueSerializer[_Relation2Serializer__R], scala.Product, scala.Serializable, typing.Generic[_Relation2Serializer__S1, _Relation2Serializer__S2, _Relation2Serializer__R]):
    def __init__(self, opDesc: sigmastate.RelationCompanion, constructor: scala.Function2[sigmastate.Values.Value[_Relation2Serializer__S1], sigmastate.Values.Value[_Relation2Serializer__S2], sigmastate.Values.Value[sigmastate.SBoolean.]]): ...
    _apply__S1 = typing.TypeVar('_apply__S1', bound=sigmastate.SType)  # <S1>
    _apply__S2 = typing.TypeVar('_apply__S2', bound=sigmastate.SType)  # <S2>
    _apply__R = typing.TypeVar('_apply__R', bound=sigmastate.Values.Value)  # <R>
    @staticmethod
    def apply(opDesc: sigmastate.RelationCompanion, constructor: scala.Function2[sigmastate.Values.Value[_apply__S1], sigmastate.Values.Value[_apply__S2], sigmastate.Values.Value[sigmastate.SBoolean.]]) -> 'Relation2Serializer'[_apply__S1, _apply__S2, _apply__R]: ...
    def bitsInfo(self) -> sigmastate.utils.SigmaByteWriter.DataInfo[sigmastate.utils.SigmaByteWriter.Bits]: ...
    def canEqual(self, x$1: typing.Any) -> bool: ...
    def constructor(self) -> scala.Function2[sigmastate.Values.Value[_Relation2Serializer__S1], sigmastate.Values.Value[_Relation2Serializer__S2], sigmastate.Values.Value[sigmastate.SBoolean.]]: ...
    _copy__S1 = typing.TypeVar('_copy__S1', bound=sigmastate.SType)  # <S1>
    _copy__S2 = typing.TypeVar('_copy__S2', bound=sigmastate.SType)  # <S2>
    _copy__R = typing.TypeVar('_copy__R', bound=sigmastate.Values.Value)  # <R>
    def copy(self, opDesc: sigmastate.RelationCompanion, constructor: scala.Function2[sigmastate.Values.Value[sigmastate.SType], sigmastate.Values.Value[sigmastate.SType], sigmastate.Values.Value[sigmastate.SBoolean.]]) -> 'Relation2Serializer'[sigmastate.SType, sigmastate.SType, sigmastate.Values.Value]: ...
    _copy$default$1__S1 = typing.TypeVar('_copy$default$1__S1', bound=sigmastate.SType)  # <S1>
    _copy$default$1__S2 = typing.TypeVar('_copy$default$1__S2', bound=sigmastate.SType)  # <S2>
    _copy$default$1__R = typing.TypeVar('_copy$default$1__R', bound=sigmastate.Values.Value)  # <R>
    def copy$default$1(self) -> sigmastate.RelationCompanion: ...
    _copy$default$2__S1 = typing.TypeVar('_copy$default$2__S1', bound=sigmastate.SType)  # <S1>
    _copy$default$2__S2 = typing.TypeVar('_copy$default$2__S2', bound=sigmastate.SType)  # <S2>
    _copy$default$2__R = typing.TypeVar('_copy$default$2__R', bound=sigmastate.Values.Value)  # <R>
    def copy$default$2(self) -> scala.Function2[sigmastate.Values.Value[sigmastate.SType], sigmastate.Values.Value[sigmastate.SType], sigmastate.Values.Value[sigmastate.SBoolean.]]: ...
    def equals(self, x$1: typing.Any) -> bool: ...
    def hashCode(self) -> int: ...
    def leftArgInfo(self) -> sigmastate.utils.SigmaByteWriter.DataInfo[sigmastate.Values.Value[sigmastate.SType]]: ...
    def opCodeInfo(self) -> sigmastate.utils.SigmaByteWriter.DataInfo[typing.Any]: ...
    def opDesc(self) -> sigmastate.RelationCompanion: ...
    def parse(self, r: sigmastate.utils.SigmaByteReader) -> _Relation2Serializer__R: ...
    def productArity(self) -> int: ...
    def productElement(self, x$1: int) -> typing.Any: ...
    def productIterator(self) -> scala.collection.Iterator[typing.Any]: ...
    def productPrefix(self) -> java.lang.String: ...
    def rightArgInfo(self) -> sigmastate.utils.SigmaByteWriter.DataInfo[sigmastate.Values.Value[sigmastate.SType]]: ...
    def serialize(self, obj: _Relation2Serializer__R, w: sigmastate.utils.SigmaByteWriter) -> None: ...
    def toString(self) -> java.lang.String: ...
    _unapply__S1 = typing.TypeVar('_unapply__S1', bound=sigmastate.SType)  # <S1>
    _unapply__S2 = typing.TypeVar('_unapply__S2', bound=sigmastate.SType)  # <S2>
    _unapply__R = typing.TypeVar('_unapply__R', bound=sigmastate.Values.Value)  # <R>
    @staticmethod
    def unapply(x$0: 'Relation2Serializer'[_unapply__S1, _unapply__S2, _unapply__R]) -> scala.Option[scala.Tuple2[sigmastate.RelationCompanion, scala.Function2[sigmastate.Values.Value[_unapply__S1], sigmastate.Values.Value[_unapply__S2], sigmastate.Values.Value[sigmastate.SBoolean.]]]]: ...


class __module_protocol__(typing.Protocol):
    # A module protocol which reflects the result of ``jp.JPackage("sigmastate.serialization.trees")``.

    QuadrupleSerializer: typing.Type[QuadrupleSerializer]
    Relation2Serializer: typing.Type[Relation2Serializer]



import org.ergoplatform.settings
import typing



class EmissionRules:
    def __init__(self, settings: org.ergoplatform.settings.MonetarySettings): ...
    @staticmethod
    def CoinsInOneErgo() -> int: ...
    def blocksTotal(self) -> int: ...
    def coinsTotal(self) -> int: ...
    def emissionAtHeight(self, h: int) -> int: ...
    def foundationRewardAtHeight(self, h: int) -> int: ...
    def foundersCoinsTotal(self) -> int: ...
    def issuedCoinsAfterHeight(self, h: int) -> int: ...
    def minersCoinsTotal(self) -> int: ...
    def minersRewardAtHeight(self, h: int) -> int: ...
    def remainingCoinsAfterHeight(self, h: int) -> int: ...
    def remainingFoundationRewardAtHeight(self, h: int) -> int: ...
    def settings(self) -> org.ergoplatform.settings.MonetarySettings: ...


class __module_protocol__(typing.Protocol):
    # A module protocol which reflects the result of ``jp.JPackage("org.ergoplatform.mining.emission")``.

    EmissionRules: typing.Type[EmissionRules]



import java
import java.io
import java.lang
import java.nio
import java.nio.charset
import java.nio.file.attribute
import java.time
import java.util
import java.util.stream
import jpype.protocol
import typing



class CheckedInputStream(java.io.FilterInputStream):
    def __init__(self, inputStream: java.io.InputStream, checksum: 'Checksum'): ...
    def getChecksum(self) -> 'Checksum': ...
    @typing.overload
    def read(self, byteArray: typing.List[int]) -> int: ...
    @typing.overload
    def read(self) -> int: ...
    @typing.overload
    def read(self, byteArray: typing.List[int], int: int, int2: int) -> int: ...
    def skip(self, long: int) -> int: ...

class CheckedOutputStream(java.io.FilterOutputStream):
    def __init__(self, outputStream: java.io.OutputStream, checksum: 'Checksum'): ...
    def getChecksum(self) -> 'Checksum': ...
    @typing.overload
    def write(self, byteArray: typing.List[int]) -> None: ...
    @typing.overload
    def write(self, byteArray: typing.List[int], int: int, int2: int) -> None: ...
    @typing.overload
    def write(self, int: int) -> None: ...

class Checksum:
    def getValue(self) -> int: ...
    def reset(self) -> None: ...
    @typing.overload
    def update(self, byteArray: typing.List[int], int: int, int2: int) -> None: ...
    @typing.overload
    def update(self, int: int) -> None: ...
    @typing.overload
    def update(self, byteArray: typing.List[int]) -> None: ...
    @typing.overload
    def update(self, byteBuffer: java.nio.ByteBuffer) -> None: ...

class DataFormatException(java.lang.Exception):
    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, string: str): ...

class Deflater:
    DEFLATED: typing.ClassVar[int] = ...
    NO_COMPRESSION: typing.ClassVar[int] = ...
    BEST_SPEED: typing.ClassVar[int] = ...
    BEST_COMPRESSION: typing.ClassVar[int] = ...
    DEFAULT_COMPRESSION: typing.ClassVar[int] = ...
    FILTERED: typing.ClassVar[int] = ...
    HUFFMAN_ONLY: typing.ClassVar[int] = ...
    DEFAULT_STRATEGY: typing.ClassVar[int] = ...
    NO_FLUSH: typing.ClassVar[int] = ...
    SYNC_FLUSH: typing.ClassVar[int] = ...
    FULL_FLUSH: typing.ClassVar[int] = ...
    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, int: int): ...
    @typing.overload
    def __init__(self, int: int, boolean: bool): ...
    @typing.overload
    def deflate(self, byteArray: typing.List[int]) -> int: ...
    @typing.overload
    def deflate(self, byteArray: typing.List[int], int: int, int2: int) -> int: ...
    @typing.overload
    def deflate(self, byteArray: typing.List[int], int: int, int2: int, int3: int) -> int: ...
    @typing.overload
    def deflate(self, byteBuffer: java.nio.ByteBuffer) -> int: ...
    @typing.overload
    def deflate(self, byteBuffer: java.nio.ByteBuffer, int: int) -> int: ...
    def end(self) -> None: ...
    def finish(self) -> None: ...
    def finished(self) -> bool: ...
    def getAdler(self) -> int: ...
    def getBytesRead(self) -> int: ...
    def getBytesWritten(self) -> int: ...
    def getTotalIn(self) -> int: ...
    def getTotalOut(self) -> int: ...
    def needsInput(self) -> bool: ...
    def reset(self) -> None: ...
    @typing.overload
    def setDictionary(self, byteArray: typing.List[int]) -> None: ...
    @typing.overload
    def setDictionary(self, byteArray: typing.List[int], int: int, int2: int) -> None: ...
    @typing.overload
    def setDictionary(self, byteBuffer: java.nio.ByteBuffer) -> None: ...
    @typing.overload
    def setInput(self, byteArray: typing.List[int]) -> None: ...
    @typing.overload
    def setInput(self, byteArray: typing.List[int], int: int, int2: int) -> None: ...
    @typing.overload
    def setInput(self, byteBuffer: java.nio.ByteBuffer) -> None: ...
    def setLevel(self, int: int) -> None: ...
    def setStrategy(self, int: int) -> None: ...

class DeflaterInputStream(java.io.FilterInputStream):
    @typing.overload
    def __init__(self, inputStream: java.io.InputStream): ...
    @typing.overload
    def __init__(self, inputStream: java.io.InputStream, deflater: Deflater): ...
    @typing.overload
    def __init__(self, inputStream: java.io.InputStream, deflater: Deflater, int: int): ...
    def available(self) -> int: ...
    def close(self) -> None: ...
    def mark(self, int: int) -> None: ...
    def markSupported(self) -> bool: ...
    @typing.overload
    def read(self, byteArray: typing.List[int]) -> int: ...
    @typing.overload
    def read(self) -> int: ...
    @typing.overload
    def read(self, byteArray: typing.List[int], int: int, int2: int) -> int: ...
    def reset(self) -> None: ...
    def skip(self, long: int) -> int: ...

class DeflaterOutputStream(java.io.FilterOutputStream):
    @typing.overload
    def __init__(self, outputStream: java.io.OutputStream): ...
    @typing.overload
    def __init__(self, outputStream: java.io.OutputStream, boolean: bool): ...
    @typing.overload
    def __init__(self, outputStream: java.io.OutputStream, deflater: Deflater): ...
    @typing.overload
    def __init__(self, outputStream: java.io.OutputStream, deflater: Deflater, boolean: bool): ...
    @typing.overload
    def __init__(self, outputStream: java.io.OutputStream, deflater: Deflater, int: int): ...
    @typing.overload
    def __init__(self, outputStream: java.io.OutputStream, deflater: Deflater, int: int, boolean: bool): ...
    def close(self) -> None: ...
    def finish(self) -> None: ...
    def flush(self) -> None: ...
    @typing.overload
    def write(self, byteArray: typing.List[int]) -> None: ...
    @typing.overload
    def write(self, byteArray: typing.List[int], int: int, int2: int) -> None: ...
    @typing.overload
    def write(self, int: int) -> None: ...

class Inflater:
    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, boolean: bool): ...
    def end(self) -> None: ...
    def finished(self) -> bool: ...
    def getAdler(self) -> int: ...
    def getBytesRead(self) -> int: ...
    def getBytesWritten(self) -> int: ...
    def getRemaining(self) -> int: ...
    def getTotalIn(self) -> int: ...
    def getTotalOut(self) -> int: ...
    @typing.overload
    def inflate(self, byteArray: typing.List[int]) -> int: ...
    @typing.overload
    def inflate(self, byteArray: typing.List[int], int: int, int2: int) -> int: ...
    @typing.overload
    def inflate(self, byteBuffer: java.nio.ByteBuffer) -> int: ...
    def needsDictionary(self) -> bool: ...
    def needsInput(self) -> bool: ...
    def reset(self) -> None: ...
    @typing.overload
    def setDictionary(self, byteArray: typing.List[int]) -> None: ...
    @typing.overload
    def setDictionary(self, byteArray: typing.List[int], int: int, int2: int) -> None: ...
    @typing.overload
    def setDictionary(self, byteBuffer: java.nio.ByteBuffer) -> None: ...
    @typing.overload
    def setInput(self, byteArray: typing.List[int]) -> None: ...
    @typing.overload
    def setInput(self, byteArray: typing.List[int], int: int, int2: int) -> None: ...
    @typing.overload
    def setInput(self, byteBuffer: java.nio.ByteBuffer) -> None: ...

class InflaterInputStream(java.io.FilterInputStream):
    @typing.overload
    def __init__(self, inputStream: java.io.InputStream): ...
    @typing.overload
    def __init__(self, inputStream: java.io.InputStream, inflater: Inflater): ...
    @typing.overload
    def __init__(self, inputStream: java.io.InputStream, inflater: Inflater, int: int): ...
    def available(self) -> int: ...
    def close(self) -> None: ...
    def mark(self, int: int) -> None: ...
    def markSupported(self) -> bool: ...
    @typing.overload
    def read(self, byteArray: typing.List[int]) -> int: ...
    @typing.overload
    def read(self) -> int: ...
    @typing.overload
    def read(self, byteArray: typing.List[int], int: int, int2: int) -> int: ...
    def reset(self) -> None: ...
    def skip(self, long: int) -> int: ...

class InflaterOutputStream(java.io.FilterOutputStream):
    @typing.overload
    def __init__(self, outputStream: java.io.OutputStream): ...
    @typing.overload
    def __init__(self, outputStream: java.io.OutputStream, inflater: Inflater): ...
    @typing.overload
    def __init__(self, outputStream: java.io.OutputStream, inflater: Inflater, int: int): ...
    def close(self) -> None: ...
    def finish(self) -> None: ...
    def flush(self) -> None: ...
    @typing.overload
    def write(self, byteArray: typing.List[int]) -> None: ...
    @typing.overload
    def write(self, byteArray: typing.List[int], int: int, int2: int) -> None: ...
    @typing.overload
    def write(self, int: int) -> None: ...

class ZipError(java.lang.InternalError):
    def __init__(self, string: str): ...

class ZipException(java.io.IOException):
    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, string: str): ...

class Adler32(Checksum):
    def __init__(self): ...
    def getValue(self) -> int: ...
    def reset(self) -> None: ...
    @typing.overload
    def update(self, byteArray: typing.List[int]) -> None: ...
    @typing.overload
    def update(self, byteArray: typing.List[int], int: int, int2: int) -> None: ...
    @typing.overload
    def update(self, int: int) -> None: ...
    @typing.overload
    def update(self, byteBuffer: java.nio.ByteBuffer) -> None: ...

class CRC32(Checksum):
    def __init__(self): ...
    def getValue(self) -> int: ...
    def reset(self) -> None: ...
    @typing.overload
    def update(self, byteArray: typing.List[int]) -> None: ...
    @typing.overload
    def update(self, byteArray: typing.List[int], int: int, int2: int) -> None: ...
    @typing.overload
    def update(self, int: int) -> None: ...
    @typing.overload
    def update(self, byteBuffer: java.nio.ByteBuffer) -> None: ...

class CRC32C(Checksum):
    def __init__(self): ...
    def getValue(self) -> int: ...
    def reset(self) -> None: ...
    @typing.overload
    def update(self, byteArray: typing.List[int]) -> None: ...
    @typing.overload
    def update(self, byteArray: typing.List[int], int: int, int2: int) -> None: ...
    @typing.overload
    def update(self, int: int) -> None: ...
    @typing.overload
    def update(self, byteBuffer: java.nio.ByteBuffer) -> None: ...

class GZIPInputStream(InflaterInputStream):
    GZIP_MAGIC: typing.ClassVar[int] = ...
    @typing.overload
    def __init__(self, inputStream: java.io.InputStream): ...
    @typing.overload
    def __init__(self, inputStream: java.io.InputStream, int: int): ...
    def close(self) -> None: ...
    @typing.overload
    def read(self, byteArray: typing.List[int]) -> int: ...
    @typing.overload
    def read(self, byteArray: typing.List[int], int: int, int2: int) -> int: ...
    @typing.overload
    def read(self) -> int: ...

class GZIPOutputStream(DeflaterOutputStream):
    @typing.overload
    def __init__(self, outputStream: java.io.OutputStream): ...
    @typing.overload
    def __init__(self, outputStream: java.io.OutputStream, boolean: bool): ...
    @typing.overload
    def __init__(self, outputStream: java.io.OutputStream, int: int): ...
    @typing.overload
    def __init__(self, outputStream: java.io.OutputStream, int: int, boolean: bool): ...
    def finish(self) -> None: ...
    @typing.overload
    def write(self, byteArray: typing.List[int], int: int, int2: int) -> None: ...
    @typing.overload
    def write(self, byteArray: typing.List[int]) -> None: ...
    @typing.overload
    def write(self, int: int) -> None: ...

class ZipEntry(java.util.zip.ZipConstants, java.lang.Cloneable):
    STORED: typing.ClassVar[int] = ...
    DEFLATED: typing.ClassVar[int] = ...
    @typing.overload
    def __init__(self, string: str): ...
    @typing.overload
    def __init__(self, zipEntry: 'ZipEntry'): ...
    def clone(self) -> typing.Any: ...
    def getComment(self) -> str: ...
    def getCompressedSize(self) -> int: ...
    def getCrc(self) -> int: ...
    def getCreationTime(self) -> java.nio.file.attribute.FileTime: ...
    def getExtra(self) -> typing.List[int]: ...
    def getLastAccessTime(self) -> java.nio.file.attribute.FileTime: ...
    def getLastModifiedTime(self) -> java.nio.file.attribute.FileTime: ...
    def getMethod(self) -> int: ...
    def getName(self) -> str: ...
    def getSize(self) -> int: ...
    def getTime(self) -> int: ...
    def getTimeLocal(self) -> java.time.LocalDateTime: ...
    def hashCode(self) -> int: ...
    def isDirectory(self) -> bool: ...
    def setComment(self, string: str) -> None: ...
    def setCompressedSize(self, long: int) -> None: ...
    def setCrc(self, long: int) -> None: ...
    def setCreationTime(self, fileTime: java.nio.file.attribute.FileTime) -> 'ZipEntry': ...
    def setExtra(self, byteArray: typing.List[int]) -> None: ...
    def setLastAccessTime(self, fileTime: java.nio.file.attribute.FileTime) -> 'ZipEntry': ...
    def setLastModifiedTime(self, fileTime: java.nio.file.attribute.FileTime) -> 'ZipEntry': ...
    def setMethod(self, int: int) -> None: ...
    def setSize(self, long: int) -> None: ...
    def setTime(self, long: int) -> None: ...
    def setTimeLocal(self, localDateTime: java.time.LocalDateTime) -> None: ...
    def toString(self) -> str: ...

class ZipFile(java.util.zip.ZipConstants, java.io.Closeable):
    OPEN_READ: typing.ClassVar[int] = ...
    OPEN_DELETE: typing.ClassVar[int] = ...
    @typing.overload
    def __init__(self, file: typing.Union[java.io.File, jpype.protocol.SupportsPath]): ...
    @typing.overload
    def __init__(self, file: typing.Union[java.io.File, jpype.protocol.SupportsPath], int: int): ...
    @typing.overload
    def __init__(self, file: typing.Union[java.io.File, jpype.protocol.SupportsPath], int: int, charset: java.nio.charset.Charset): ...
    @typing.overload
    def __init__(self, file: typing.Union[java.io.File, jpype.protocol.SupportsPath], charset: java.nio.charset.Charset): ...
    @typing.overload
    def __init__(self, string: str): ...
    @typing.overload
    def __init__(self, string: str, charset: java.nio.charset.Charset): ...
    def close(self) -> None: ...
    def entries(self) -> java.util.Enumeration[ZipEntry]: ...
    def getComment(self) -> str: ...
    def getEntry(self, string: str) -> ZipEntry: ...
    def getInputStream(self, zipEntry: ZipEntry) -> java.io.InputStream: ...
    def getName(self) -> str: ...
    def size(self) -> int: ...
    def stream(self) -> java.util.stream.Stream[ZipEntry]: ...

class ZipInputStream(InflaterInputStream, java.util.zip.ZipConstants):
    @typing.overload
    def __init__(self, inputStream: java.io.InputStream): ...
    @typing.overload
    def __init__(self, inputStream: java.io.InputStream, charset: java.nio.charset.Charset): ...
    def available(self) -> int: ...
    def close(self) -> None: ...
    def closeEntry(self) -> None: ...
    def getNextEntry(self) -> ZipEntry: ...
    @typing.overload
    def read(self, byteArray: typing.List[int]) -> int: ...
    @typing.overload
    def read(self) -> int: ...
    @typing.overload
    def read(self, byteArray: typing.List[int], int: int, int2: int) -> int: ...
    def skip(self, long: int) -> int: ...

class ZipOutputStream(DeflaterOutputStream, java.util.zip.ZipConstants):
    STORED: typing.ClassVar[int] = ...
    DEFLATED: typing.ClassVar[int] = ...
    @typing.overload
    def __init__(self, outputStream: java.io.OutputStream): ...
    @typing.overload
    def __init__(self, outputStream: java.io.OutputStream, charset: java.nio.charset.Charset): ...
    def close(self) -> None: ...
    def closeEntry(self) -> None: ...
    def finish(self) -> None: ...
    def putNextEntry(self, zipEntry: ZipEntry) -> None: ...
    def setComment(self, string: str) -> None: ...
    def setLevel(self, int: int) -> None: ...
    def setMethod(self, int: int) -> None: ...
    @typing.overload
    def write(self, byteArray: typing.List[int], int: int, int2: int) -> None: ...
    @typing.overload
    def write(self, byteArray: typing.List[int]) -> None: ...
    @typing.overload
    def write(self, int: int) -> None: ...

class ZipConstants: ...


class __module_protocol__(typing.Protocol):
    # A module protocol which reflects the result of ``jp.JPackage("java.util.zip")``.

    Adler32: typing.Type[Adler32]
    CRC32: typing.Type[CRC32]
    CRC32C: typing.Type[CRC32C]
    CheckedInputStream: typing.Type[CheckedInputStream]
    CheckedOutputStream: typing.Type[CheckedOutputStream]
    Checksum: typing.Type[Checksum]
    DataFormatException: typing.Type[DataFormatException]
    Deflater: typing.Type[Deflater]
    DeflaterInputStream: typing.Type[DeflaterInputStream]
    DeflaterOutputStream: typing.Type[DeflaterOutputStream]
    GZIPInputStream: typing.Type[GZIPInputStream]
    GZIPOutputStream: typing.Type[GZIPOutputStream]
    Inflater: typing.Type[Inflater]
    InflaterInputStream: typing.Type[InflaterInputStream]
    InflaterOutputStream: typing.Type[InflaterOutputStream]
    ZipConstants: typing.Type[ZipConstants]
    ZipEntry: typing.Type[ZipEntry]
    ZipError: typing.Type[ZipError]
    ZipException: typing.Type[ZipException]
    ZipFile: typing.Type[ZipFile]
    ZipInputStream: typing.Type[ZipInputStream]
    ZipOutputStream: typing.Type[ZipOutputStream]
